@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2023
+#  Copyright (c) 1997-2020
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -202,7 +202,7 @@ $title
       $head .= <<"%";
 			<div class=group id='explode_OUTPUTID'>
 				<strong>Explode</strong>
-				<input id='explodeRange_OUTPUTID' type='range' min='0.00001' max=6 step=0.01 value=0.00001>
+				<input id='explodeRange_OUTPUTID' type='range' min=0 max=6 step=0.01 value=0>
 				<div class=indented><input id='explodeCheckbox_OUTPUTID' type='checkbox'>Automatic explosion</div>
 				<div class=suboption>Exploding speed</div>
 				<input id='explodingSpeedRange_OUTPUTID' type='range' min=0 max=0.5 step=0.001 value=0.05>
@@ -215,7 +215,6 @@ $title
 			<div class=group id='transparency_OUTPUTID' class='transparency'>
 				<strong>Transparency</strong>
 				<input id='transparencyRange_OUTPUTID' type='range' min=0 max=1 step=0.01 value=0>
-            <div class=indented><input id='depthWriteCheckbox_OUTPUTID' type='checkbox'>depthWrite</div>
 			</div>
 			
 			<div class=group id='rotation_OUTPUTID'>
@@ -547,7 +546,7 @@ sub writePointRadii {
    my $radii = $self->source->VertexThickness // 1;
    my $number = @{$self->source->Vertices};
    if (is_code($radii)) {
-      $string .= "$objvar.userData.pointradii = ".Utils::jsArray(map { $radii->($_)/50 } (0..$number-1)).";\n";
+      $string .= "$objvar.userData.pointradii = ".Utils::jsArray(map { $radii->($_)/50 } (0..$number)).";\n";
    } else {
       $string .= "$objvar.userData.pointradii = " . $radii/50 . ";\n";   
    }
@@ -573,7 +572,7 @@ sub writePointLabels {
 
 sub writeEdgeMaterial {
    my ($self,$objvar)=@_;
-   my $props = { transparent => "false" };
+   my $props = { transparent => "false", depthTest => "true"};
    my $mtype = "LineBasicMaterial";
    my @type_props = ("EdgeColor", "EdgeThickness");
    my $string = "   <!-- Edge style -->\n";
@@ -746,7 +745,7 @@ sub writeFacetIndices {
 
 sub writeFacetMaterial {
    my ($self,$objvar)=@_;
-   my $props = { side => "THREE.DoubleSide", transparent => "true", depthWrite => "false", depthFunc => "THREE.LessDepth", polygonOffset => "true", polygonOffsetFactor => 1, polygonOffsetUnits => 0.5};
+   my $props = { side => "THREE.DoubleSide", transparent => "true", depthFunc => "THREE.LessDepth", polygonOffset => "true", polygonOffsetFactor => 1, polygonOffsetUnits => 0.5};
    my $mtype = "MeshBasicMaterial";
    my @type_props = ("FacetColor", "FacetTransparency");
    my $text = "   <!-- Facet style -->\n";
