@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -19,7 +20,7 @@
 
 namespace polymake { namespace graph {
 
-void SpringEmbedder::init_params(const perl::OptionSet& options)
+void SpringEmbedder::init_params(const OptionSet& options)
 {
    if (!(options["eps"] >> epsilon)) epsilon=1e-4;
    epsilon_2=epsilon*epsilon;
@@ -33,7 +34,7 @@ void SpringEmbedder::init_params(const perl::OptionSet& options)
    if (!(options["z-factor"] >> z_factor)) z_factor=1;
 
    if (options["z-ordering"] >> z_ordering) {
-      Entire< Vector<double> >::const_iterator obj=entire(z_ordering);
+      auto obj=entire(z_ordering);
       double z_order_min=*obj, z_order_max=z_order_min;
       while (!(++obj).at_end())
          pm::assign_min_max(z_order_min, z_order_max, *obj);
@@ -41,7 +42,7 @@ void SpringEmbedder::init_params(const perl::OptionSet& options)
       const double z_mid=(z_order_max+z_order_min)/2;
       z_order_max-=z_order_min;
       if (z_order_max > 1e-3*scale) {
-         for (Entire< Vector<double> >::iterator obj=entire(z_ordering); !obj.at_end(); ++obj)
+         for (obj=entire(z_ordering); !obj.at_end(); ++obj)
             *obj=(*obj-z_mid)/z_order_max;
       } else {
          z_ordering.clear();
@@ -54,37 +55,37 @@ void SpringEmbedder::init_params(const perl::OptionSet& options)
    G.init_edge_map(inv_wanted_length);
 
    if (options["edge-weights"] >> wanted_edge_length) {
-      min_edge_weight=std::numeric_limits<double>::infinity();
-      avg_edge_weight=0;
+      min_edge_weight = std::numeric_limits<double>::infinity();
+      avg_edge_weight = 0;
 
-      for (Entire< std::vector<double> >::iterator e=entire(wanted_edge_length); !e.at_end(); ++e) {
+      for (auto e = entire(wanted_edge_length); !e.at_end(); ++e) {
          if (*e <= 0)
             throw std::runtime_error("non-positive edge length encountered");
          pm::assign_min(min_edge_weight, *e);
          avg_edge_weight += *e;
       }
-      avg_edge_weight/=(min_edge_weight*G.edges());
+      avg_edge_weight /= min_edge_weight * double(G.edges());
    } else {
-      min_edge_weight=1/scale;
-      avg_edge_weight=scale;
+      min_edge_weight = 1/scale;
+      avg_edge_weight = scale;
       fill_range(entire(wanted_edge_length), avg_edge_weight);
    }
 
-   for (Entire< std::vector<double> >::iterator e=entire(wanted_edge_length), ie=entire(inv_wanted_length);
+   for (auto e = entire(wanted_edge_length), ie = entire(inv_wanted_length);
         !e.at_end(); ++e, ++ie)
-      *ie=min_edge_weight/(*e);
+      *ie = min_edge_weight/(*e);
 
-   gravity=true;
+   gravity = true;
 
-   const double n_nodes=G.nodes();
-   eff_scale=avg_edge_weight/4*std::sqrt(n_nodes);
-   const double avg_deg=2.0*G.edges()/n_nodes;
-   if (avg_deg>=3) {
-      const double x=2*M_PI/avg_deg;
-      eff_scale*=std::sqrt(std::sin(x)/x);
+   const double n_nodes = double(G.nodes());
+   eff_scale = avg_edge_weight/4*std::sqrt(n_nodes);
+   const double avg_deg = 2*double(G.edges())/n_nodes;
+   if (avg_deg >= 3) {
+      const double x = 2*M_PI/avg_deg;
+      eff_scale *= std::sqrt(std::sin(x)/x);
    }
 #if POLYMAKE_DEBUG
-   debug_print = perl::get_debug_level() > 1;
+   debug_print = get_debug_level() > 1;
    if (debug_print) {
       cout << "initial adjustment:"
               "\n  min_edge_weight=" << min_edge_weight
@@ -109,15 +110,13 @@ void SpringEmbedder::restart(const Matrix<double>& X)
 
 void SpringEmbedder::calculate_forces(const Matrix<double>& X, RandomSpherePoints<double>& random_points, Matrix<double>& F)
 {
-   Rows< Matrix<double> >::iterator f=rows(F).begin();
-   Entire< Vector<double> >::const_iterator z=entire(z_ordering);
-   double new_z_min=X[0].back(), new_z_max=new_z_min;
-   z_max-=z_min;
+   auto f = rows(F).begin();
+   auto z = entire(z_ordering);
+   double new_z_min = X[0].back(), new_z_max=new_z_min;
+   z_max -= z_min;
    if (gravity) barycenter.fill(0.);
 
-   for (Entire< Nodes< Graph<> > >::const_iterator this_node=entire(nodes(G));  
-        !this_node.at_end(); ++this_node, ++f) {
-
+   for (auto this_node = entire(nodes(G)); !this_node.at_end(); ++this_node, ++f) {
       f->fill(0.);
       if (gravity) barycenter += X[*this_node];
 
@@ -128,9 +127,9 @@ void SpringEmbedder::calculate_forces(const Matrix<double>& X, RandomSpherePoint
          ++z;
       }
 
-      Graph<>::out_edge_list::const_iterator edge=this_node.out_edges().begin();
+      auto edge = this_node.out_edges().begin();
 
-      for (Entire< Nodes< Graph<> > >::const_iterator n2=entire(nodes(G)); n2!=this_node; ++n2) {
+      for (auto n2 = entire(nodes(G)); n2 != this_node; ++n2) {
          const Vector<double> delta = X[*n2] - X[*this_node];
          const double delta_sqr=sqr(delta);
          if (delta_sqr>epsilon_2) {
@@ -159,17 +158,28 @@ void SpringEmbedder::calculate_forces(const Matrix<double>& X, RandomSpherePoint
       }
    }
 
-   z_min=new_z_min;  z_max=new_z_max;
+   z_min = new_z_min;
+   z_max = new_z_max;
    if (gravity) {
-      barycenter /= X.rows();
-      if (!z_ordering.empty()) barycenter.back()=0;
+      barycenter /= double(X.rows());
+      if (!z_ordering.empty()) barycenter.back() = 0;
    }
 
-   for (Entire< Set<int> >::const_iterator fi = entire(fixed_vertices); !fi.at_end(); ++fi)
+   for (auto fi = entire(fixed_vertices); !fi.at_end(); ++fi)
       F[*fi].fill(0);
+
+   // cap the force magnitude to prevent explosions
+   constexpr double max_f_proj = 1e6;
+   constexpr double max_f_sqr = 3 * max_f_proj * max_f_proj;
+
+   for (auto ff = entire(rows(F)); !ff.at_end(); ++ff) {
+      const double f_sqr = sqr(*ff);
+      if (f_sqr > max_f_sqr) *ff *= max_f_sqr / f_sqr;
+   }
 }
 
-static inline
+namespace {
+
 void calc_internal_constants(double& a, double& b, double& c, double& d, double viscosity, double inertion)
 {
    a=std::exp(-viscosity/inertion);
@@ -178,32 +188,33 @@ void calc_internal_constants(double& a, double& b, double& c, double& d, double
    d=(1-c)/viscosity;
 }
 
-bool SpringEmbedder::calculate(Matrix<double>& X, RandomSpherePoints<double>& random_points, int max_iterations)
+}
+
+bool SpringEmbedder::calculate(Matrix<double>& X, RandomSpherePoints<double>& random_points, Int max_iterations)
 {
-   const int n_nodes=G.nodes();
+   const Int n_nodes = G.nodes();
    Matrix<double> F(n_nodes,X.cols());  // forces
 
    const double viscosity_increasing_factor=1.2;
 
-   int incr_viscosity=0, decr_viscosity=0;
-   double a,b,c,d;
-   calc_internal_constants(a,b,c,d,viscosity,inertion);
+   Int incr_viscosity = 0, decr_viscosity = 0;
+   double a, b, c, d;
+   calc_internal_constants(a, b, c, d, viscosity, inertion);
 
-   for (int iter=0; iter<max_iterations; ++iter) {
-      calculate_forces(X,random_points,F);
+   for (Int iter = 0; iter < max_iterations; ++iter) {
+      calculate_forces(X, random_points, F);
 #if POLYMAKE_DEBUG
       if (debug_print) cout << "iteration " << iter << endl;
 #endif
 
-      int oscillated=0, moved=0;
-      Rows< Matrix<double> >::iterator x=rows(X).begin(), f=rows(F).begin(), v=rows(V).begin();
-      for (Entire< Nodes< Graph<> > >::const_iterator this_node=entire(nodes(G));
-           !this_node.at_end();  ++this_node, ++x, ++f, ++v) {
+      Int oscillated = 0, moved = 0;
+      auto x = rows(X).begin(), f = rows(F).begin(), v = rows(V).begin();
+      for (auto this_node = entire(nodes(G)); !this_node.at_end();  ++this_node, ++x, ++f, ++v) {
 #if POLYMAKE_DEBUG
          if (debug_print) cout << '[' << *this_node << "]: x=(" << *x << "); f=(" << *f << "); v=(" << *v << ")\n";
 #endif
-         Vector<double> v1=a*(*v) + b*(*f),
-                        dx=c*(*v) + d*(*f);
+         Vector<double> v1 = a*(*v) + b*(*f),
+                        dx = c*(*v) + d*(*f);
          if (sqr(dx) >= epsilon_2) {
             if ((*v) * v1 < 0)
                ++oscillated;
