@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -19,27 +20,27 @@
 
 namespace polymake { namespace graph {
 
-perl::Object complete(const int n)
+BigObject complete(const Int n)
 {
    if (n < 1)
       throw std::runtime_error("number of nodes must be positive");
 
    Graph<> g(n);
-   for (int i=0; i<n-1; ++i)
-     for (int j=i+1; j<n; ++j)
-       g.edge(i,j);
-   perl::Object G("Graph<>");
-   G.take("N_NODES")   << n;
-   G.take("N_EDGES")   << (n*(n-1)/2);
-   G.take("DIAMETER")  << 1;
-   G.take("CONNECTED") << true;
-   G.take("BIPARTITE") << (n<=2);
-   G.take("ADJACENCY") << g;
-   G.set_description() << "Complete graph on "<<n<< " nodes."<<endl;
+   for (Int i = 0; i < n-1; ++i)
+     for (Int j = i+1; j < n; ++j)
+       g.edge(i, j);
+   BigObject G("Graph<>",
+               "N_NODES", n,
+               "N_EDGES", (n*(n-1)/2),
+               "DIAMETER", 1,
+               "CONNECTED", true,
+               "BIPARTITE", n <= 2,
+               "ADJACENCY", g);
+   G.set_description() << "Complete graph on " << n << " nodes." << endl;
    return G;
 
 }
-UserFunction4perl("# @category Producing a graph\n"
+UserFunction4perl("# @category Producing a graph"
                   "# Constructs a __complete graph__ on //n// nodes."
                   "# @param Int n"
                   "# @return Graph"
