@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -17,6 +18,7 @@
 #include "polymake/client.h"
 #include "polymake/Array.h"
 #include "polymake/Set.h"
+#include "polymake/ApproximateSet.h"
 #include "polymake/Matrix.h"
 #include "polymake/Vector.h"
 #include "polymake/Rational.h"
@@ -27,46 +29,61 @@
 
 namespace polymake { namespace group {
 
+namespace {      
+
+template <typename Element>
+struct set_chooser {
+   typedef hash_set<Element> type;
+};
+
+template <>
+struct set_chooser<Matrix<double>> {
+   typedef ApproximateSet<Matrix<double>> type;
+};
+   
+   
 template<typename Element>
 auto
 all_group_elements_impl(const Array<Element>& generators)
 {
-   return orbit_impl<LeftAction<Element>, Element, Element>(generators, identity(degree(generators[0]), Element()));
+   return orbit_impl<LeftAction<Element>, Element, Element, typename set_chooser<Element>::type>(generators, identity(degree(generators[0]), Element()));
+}
+   
+template<typename Element>
+auto
+conjugacy_class_impl(const Array<Element>& generators,
+                     const Element& class_rep)
+{
+   return Set<Element>(entire(orbit_impl<ConjugationAction<Element>, Element, Element, typename set_chooser<Element>::type>(generators, class_rep)));
 }
 
-template<typename Scalar>
+} // end anonymous namespace
+      
+template <typename Scalar>
 auto
-all_group_elements(perl::Object MatrixAction)
+all_group_elements(BigObject MatrixAction)
 {
    const Array<Matrix<Scalar>> generators = MatrixAction.give("GENERATORS");
    return Set<Matrix<Scalar>>(entire(all_group_elements_impl(generators)));
 }
 
-template<typename Element>
+template <typename Element>
 auto conjugacy_classes(const Array<Element>& generators, 
                        const Array<Element>& conjugacy_classes_representatives)
 {
    Array<Set<Element>> conjugacy_classes(conjugacy_classes_representatives.size());
-   for (int i=0; i<conjugacy_classes_representatives.size(); ++i)
-      conjugacy_classes[i] = Set<Element>(entire(orbit_impl<ConjugationAction<Element>, Element, Element>(generators, conjugacy_classes_representatives[i])));
+   for (Int i = 0; i<conjugacy_classes_representatives.size(); ++i)
+      conjugacy_classes[i] = conjugacy_class_impl(generators, conjugacy_classes_representatives[i]);
 
    return conjugacy_classes;
 }
 
 template<typename Element>
-auto conjugacy_class(perl::Object A, const Element& element)
+auto conjugacy_class(BigObject A, const Element& element)
 {
    const Array<Element> generators = A.give("GENERATORS");
-   return Set<Element>(entire(orbit_impl<ConjugationAction<Element>, Element, Element>(generators, element)));
+   return conjugacy_class_impl(generators, element);
 }
-
-template<typename Scalar>
-auto conjugacy_class(perl::Object A, const Matrix<Scalar>& element)
-{
-   const Array<Matrix<Scalar>> generators = A.give("GENERATORS");
-   return Set<Matrix<Scalar>>(entire(orbit_impl<ConjugationAction<Matrix<Scalar>>, Matrix<Scalar>, Matrix<Scalar>>(generators, element)));
-}
-      
       
 template<typename Element>
 auto conjugacy_classes_and_reps(const Array<Element>& generators)
@@ -76,13 +93,13 @@ auto conjugacy_classes_and_reps(const Array<Element>& generators)
    std::vector<Set<Element>> classes;
    std::vector<Element> reps;
    while (sorted_group.size()) {
-      const Set<Element> new_class(entire(orbit_impl<ConjugationAction<Element>, Element, Element>(generators, sorted_group.front())));
+      const Set<Element> new_class(entire(orbit_impl<ConjugationAction<Element>, Element, Element, typename set_chooser<Element>::type>(generators, sorted_group.front())));
       classes.push_back(new_class);
       reps.push_back(classes.back().front());
       sorted_group -= new_class;
    }
-   return std::make_pair(Array<Set<Element>>(classes.size(), entire(classes)),
-                         Array<Element>(reps.size(), entire(reps)));
+   return std::make_pair(Array<Set<Element>>(classes.size(), classes.begin()),
+                         Array<Element>(reps.size(), reps.begin()));
 }
       
 
@@ -134,7 +151,7 @@ UserFunctionTemplate4perl("# @category Symmetry"
                           "# @param MatrixActionOnVectors<Scalar> action the action of the group"
                           "# @param Matrix<Scalar> e the element to be acted upon"
                           "# @tparam Scalar E the underlying number type"
-                          "# @return Set<Matrix<Element>> S a set containing the conjugacy class of the element",
+                          "# @return Set<Matrix<Scalar>> S a set containing the conjugacy class of the element",
                           "conjugacy_class<Scalar>(MatrixActionOnVectors<Scalar> Matrix<Scalar>)");
       
 FunctionTemplate4perl("conjugacy_classes_and_reps<Element>(Array<Element>)");
