@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -28,7 +29,9 @@ template <typename Iterator> inline
 void canonicalize_oriented(Iterator&& it)
 {
   typedef typename pm::iterator_traits<Iterator>::value_type Scalar;
-   if (!it.at_end() && !abs_equal(*it, one_value<Scalar>())) {
+  while (!it.at_end() && is_zero(*it))
+    ++it;
+  if (!it.at_end() && !abs_equal(*it, one_value<Scalar>())) {
       const Scalar leading=abs(*it);
       auto&& tail=ensure_private_mutable(std::forward<Iterator>(it));
       do *tail /= leading; while (!(++tail).at_end());
