@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -23,19 +24,19 @@
 namespace polymake { namespace polytope {
 
 template <typename Scalar> 
-void facets_of_simplex(const Set<int>& simplex, const Matrix<Scalar>& V, Matrix<Scalar>& facets, Matrix<Scalar>& hull)
+void facets_of_simplex(const Set<Int>& simplex, const Matrix<Scalar>& V, Matrix<Scalar>& facets, Matrix<Scalar>& hull)
 {
    if (rank(V.minor(simplex, All)) != simplex.size()){
       throw std::runtime_error("Affinely dependent point configuration wants to be a simplex");
    }
    hull = null_space(V.minor(simplex, All));
    facets = Matrix<Scalar>(simplex.size(), V.cols());
-   int i(0);
-   for (Entire<Subsets_less_1<const Set<int>&> >::const_iterator fbi=entire(all_subsets_less_1(simplex)); !fbi.at_end(); ++fbi, ++i) {
-      const Set<int> facet(*fbi);
+   Int i = 0;
+   for (auto fbi = entire(all_subsets_less_1(simplex)); !fbi.at_end(); ++fbi, ++i) {
+      const Set<Int> facet(*fbi);
       Vector<Scalar> nv = null_space(V.minor(facet, All) / hull).row(0);
-      const Set<int> rest = simplex - facet;
-      const int v = rest.front();
+      const Set<Int> rest = simplex - facet;
+      const Int v = rest.front();
       if (nv * V.row(v) < 0) 
             nv = -nv;
       facets.row(i) = nv;
@@ -43,14 +44,14 @@ void facets_of_simplex(const Set<int>& simplex, const Matrix<Scalar>& V, Matrix<
 }
 
 template <typename Scalar> 
-bool is_empty(const Set<int>& simplex, const Matrix<Scalar>& V)
+bool is_empty(const Set<Int>& simplex, const Matrix<Scalar>& V)
 {
    if (simplex.size()==1) return true;
-   int i(0);
+   Int i = 0;
    bool has_interior(false);
    Matrix<Scalar> facets, hull;
    facets_of_simplex(simplex, V, facets, hull);
-   for (typename Entire<Rows<Matrix<Scalar> > >::const_iterator rit = entire(rows(V)); !rit.at_end() && !has_interior; ++rit, ++i){
+   for (auto rit = entire(rows(V)); !rit.at_end() && !has_interior; ++rit, ++i) {
       if (!simplex.contains(i)){
          if (hull.cols() == 0 || accumulate(attach_operation(hull*(*rit), operations::abs_value()), operations::max()) == 0) {
             if (facets.cols() != 0)
@@ -66,8 +67,8 @@ bool is_empty(const Set<int>& simplex, const Matrix<Scalar>& V)
 template<typename SetType, typename IncidenceType>
 bool is_in_boundary(const SetType& face, const IncidenceType& VIF)
 {
-   for (int f=0; f < VIF.rows(); ++f) 
-      if (incl(face, VIF.row(f))<=0) 
+   for (Int f = 0; f < VIF.rows(); ++f) 
+      if (incl(face, VIF.row(f)) <= 0) 
          return true;
    return false;   
 }
@@ -75,7 +76,7 @@ bool is_in_boundary(const SetType& face, const IncidenceType& VIF)
 template<typename SetType>
 bool is_interior(const SetType& ridge, const IncidenceMatrix<>& VIF)
 {
-    for (Entire<Rows<IncidenceMatrix<> > >::const_iterator fit = entire(rows(VIF)); !fit.at_end(); ++fit) 
+    for (auto fit = entire(rows(VIF)); !fit.at_end(); ++fit) 
         if ((ridge * (*fit)).size() == ridge.size())
             return false;
     return true;
