@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2023
+#  Copyright (c) 1997-2020
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -24,7 +24,7 @@ package Polymake::polytope::LPparser;
 # (2) LPparser($filename, $testvec, $prefix)
 #     additionally, whenever a new constraint is read in, it is checked whether $testvec satisfies it.
 #
-#     **Precondition**: The variable names in $filename **MUST** all be of the form $prefix.$i, with $i a number.
+#     **Precondition**: The variable names in $filename **MUST** all be of the from $prefix.$i, with $i a number.
 #
 #     The reason for this is that since the rows are read in on the fly, the total number and ordering
 #     of the variables are not known at the time this test takes place. Therefore, the variable names
@@ -41,8 +41,6 @@ use Polymake::Struct (
    '$ct',                       # counts how many relations have been read in
    '@Ineq',                     # inequalities Ax+B>=0, in the form (B, A)
    '@Eq',                       # equations Px+Q=0,     in the form (Q, P)
-   '@Ineq_labels',              # labels of inequalities
-   '@Eq_labels',                # labels of equations
    '%Obj',                      # objective function Cx -> min
    '@L', '@U',                  # variable bounds  l <= x <= u
    '@X',                        # variable index => name
@@ -65,7 +63,7 @@ sub new {
    push @{$self->U}, undef;
    push @{$self->X}, "inhomog_var";
 
-   open (my $LP, '<:encoding(UTF-8)', $self->LPfile)
+   open my $LP, $self->LPfile
      or die "Can't read ", $self->LPfile, ": $!\n";
    local $/;
    my $lp = <$LP>;
@@ -102,10 +100,8 @@ sub new {
 
       if ($rel=~/[<>]/) {
          push @{$self->Ineq}, $vecref;
-         push @{$self->Ineq_labels}, $label;
       } else {
          push @{$self->Eq}, $vecref;
-         push @{$self->Eq_labels}, $label;
       }
       if (defined $self->testvec) {
          my $unpermuted_vecref = $self->make_vector($line, $rel=~/</ ? "-" : "+", 1, $self->prefix);
@@ -254,6 +250,7 @@ sub new {
       }
       $line = \%permline;
    }
+   delete $self->Obj->{0};
 
    @{$self->X}=@{$self->X}[@xorder];
    @{$self->Int}=@{$self->Int}[@xorder] if @{$self->Int};
@@ -322,13 +319,7 @@ sub make_vector($$$;$$) {   # "linear expression", positive_sign => (coefficient
       $coef = parse_number($line, $positive);
       $coef.="1" if $coef eq "" or $coef eq "-";
       $i = $self->parse_name($line, $unpermuted, $prefix);
-      if (!defined($i)) {
-         if ($line =~ /^$/) {
-            $vec{0} = $coef;
-         } else {
-            die "$0: invalid expression in input line '$iline'";
-         }
-      }
+      die "$0: invalid expression in input line '$iline'" unless defined $i;
       $vec{$i} = $coef;
    }
    \%vec
