@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -20,7 +21,7 @@
 
 namespace polymake { namespace polytope {
 
-perl::Object dwarfed_product_polygons(int d, int s)
+BigObject dwarfed_product_polygons(Int d, Int s)
 {
    if (d <= 2 || d%2 != 0) {
       throw std::runtime_error("dwarfed_product_polygons: d >= 4 and even required");
@@ -29,24 +30,20 @@ perl::Object dwarfed_product_polygons(int d, int s)
       throw std::runtime_error("dwarfed_product_polygons: s >= 3 required");
    }
 
-   perl::Object p("Polytope<Rational>");
-   p.set_description() << "dwarfed product of polygons of dimension " << d << " and size " << s << endl;
-
-   Matrix<int> F((d/2)*s+1,d+1);
-   Rows<Matrix <int> >::iterator f=rows(F).begin();
-   int i;
-   for (i = 1; i<=d/2; ++i) {
+   Matrix<Int> F((d/2)*s+1,d+1);
+   auto f = rows(F).begin();
+   for (Int i = 1; i <= d/2; ++i) {
       (*f)[2*i]=1; //y_i >= 0
       ++f;
    }
-   for (i = 1; i<=d/2; ++i) {
+   for (Int i = 1; i <= d/2; ++i) {
       (*f)[2*i-1] = s; //sx_i
       (*f)[2*i] = -1; //-y_i
       ++f;
    }
 
-   for (int k = 0; k <= s-4; k++) {
-      for (i = 1; i<=d/2; ++i) {
+   for (Int k = 0; k <= s-4; ++k) {
+      for (Int i = 1; i <= d/2; ++i) {
          (*f)[2*i-1] = -2*k-1; //-(2k+1)x_i
          (*f)[2*i] = -1; //-y_i
          (*f)[0] = (2*k+1)*(s+k)-k*k+s*s;
@@ -54,25 +51,26 @@ perl::Object dwarfed_product_polygons(int d, int s)
       }
    }
 
-   for (i = 1; i<=d/2; ++i) {
+   for (Int i = 1; i <= d/2; ++i) {
       (*f)[2*i-1] = -2*s+3; //-(2*s-3)x_i
       (*f)[2*i] = -1; //-y_i
       (*f)[0] = 2*s*(2*s-3);
       ++f;
    }
     
-   //dwarfing halfspace
-   for (i=1;i<=d/2;++i) {
+   // dwarfing halfspace
+   for (Int i = 1; i <= d/2; ++i) {
       (*f)[2*i-1] = -1;
    }
    (*f)[0] = 2*s-1;
-    
-   p.take("CONE_AMBIENT_DIM") << d+1;
-   p.take("CONE_DIM") << d+1;
-   p.take("FACETS") << F;
-   p.take("BOUNDED") << true;
-   p.take("POSITIVE") << true;
 
+   BigObject p("Polytope<Rational>",
+               "CONE_AMBIENT_DIM", d+1,
+               "CONE_DIM", d+1,
+               "FACETS", F,
+               "BOUNDED", true,
+               "POSITIVE", true);
+   p.set_description() << "dwarfed product of polygons of dimension " << d << " and size " << s << endl;
    return p;
 }
 
