@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -21,14 +22,12 @@
 
 namespace polymake { namespace polytope {
 
-
-
 template <typename Scalar>
-Array<Scalar> edge_lengths(const Array<Vector<Scalar> > &V)
+Array<Scalar> edge_lengths(const Array<Vector<Scalar>>& V)
 {
-  const int n=V.size();
+  const Int n = V.size();
   Array<Scalar> length(n);
-  for (int i=0; i<n; ++i)
+  for (Int i = 0; i < n; ++i)
       length[i]=accumulate(attach_operation(V[i], operations::abs_value()), operations::max());
   return length;
 }
