@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -33,51 +34,53 @@ namespace {
 typedef Graph<Directed> PartialLattice;
 typedef NodeMap<Directed,Integer> IncidenceMap;
 
-Vector<Integer>::iterator calcEntry(const graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential>& F, PartialLattice& G, IncidenceMap& Inc, int k, Vector<Integer>::iterator fl)
+Vector<Integer>::iterator calcEntry(const graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential>& F, PartialLattice& G, IncidenceMap& Inc, Int k, Vector<Integer>::iterator fl)
 {
    // INVARIANT for G here: layer k is connected to some upper layer, all layers below k have no edges at all
-   Integer Entry=0;
-   for (auto k_node=entire(F.nodes_of_rank(k+1)); !k_node.at_end(); ++k_node)
-      Entry += (Inc[*k_node] = accumulate(select(Inc, G.out_adjacent_nodes(*k_node)), operations::add()));
+   Integer Entry = 0;
+   for (const auto k_node : F.nodes_of_rank(k+1))
+      Entry += (Inc[k_node] = accumulate(select(Inc, G.out_adjacent_nodes(k_node)), operations::add()));
 
-   int i=k-2;
-   if (i>=0) {
+   Int i = k-2;
+   if (i >= 0) {
       // connect layer k-2 with layer k
-      for (auto i_node=entire(F.nodes_of_rank(i+1)); !i_node.at_end(); ++i_node)
+      for (const auto i_node : F.nodes_of_rank(i+1))
          // iterate over the adjacent nodes in the layer between (==k-1)
-         for (PartialLattice::out_adjacent_node_list::const_iterator btw_node=F.out_adjacent_nodes(*i_node).begin(); !btw_node.at_end(); ++btw_node)
-            G.out_adjacent_nodes(*i_node) += F.out_adjacent_nodes(*btw_node);
+         for (const auto btw_node : F.out_adjacent_nodes(i_node))
+            G.out_adjacent_nodes(i_node) += F.out_adjacent_nodes(btw_node);
 
       for (;;) {
-         fl=calcEntry(F,G,Inc,i,fl);
-         if (i==0) break;
+         fl = calcEntry(F, G, Inc, i, fl);
+         if (i == 0) break;
          // move the edges from layer i to layer i-1
-         for (auto i_node=entire(F.nodes_of_rank(i+1)); !i_node.at_end(); ++i_node) {
-            for (PartialLattice::in_adjacent_node_list::const_iterator down_node=F.in_adjacent_nodes(*i_node).begin(); !down_node.at_end(); ++down_node)
-               G.out_adjacent_nodes(*down_node) += G.out_adjacent_nodes(*i_node);
-            G.out_edges(*i_node).clear();
+         for (const auto i_node : F.nodes_of_rank(i+1)) {
+            for (const auto down_node : F.in_adjacent_nodes(i_node))
+               G.out_adjacent_nodes(down_node) += G.out_adjacent_nodes(i_node);
+            G.out_edges(i_node).clear();
          }
          --i;
       }
       // remove all edges betwen layers 0 and k, thus restoring the entry invariant
-      for (auto k_node=entire(F.nodes_of_rank(k+1)); !k_node.at_end(); ++k_node)
-         G.in_edges(*k_node).clear();
+      for (const auto k_node : F.nodes_of_rank(k+1))
+         G.in_edges(k_node).clear();
    }
-   *--fl=Entry;
+   *--fl = Entry;
    return fl;
 }
+
 } // end anonymous namespace
 
-Vector<Integer> flag_vector(perl::Object HD_obj)
+Vector<Integer> flag_vector(BigObject HD_obj)
 {
    const graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential> F(HD_obj);
-   const int d = F.rank()-1;
+   const Int d = F.rank();
    PartialLattice G(F.nodes());
    IncidenceMap Inc(G);
    // provide for Inc[TOP]==1 avoiding extra conditionals in the recursive part
-   G.edge(F.top_node(), F.bottom_node()); Inc[F.bottom_node()]=1;
-   Vector<Integer> fl(fibonacci_number(d));
-   calcEntry(F,G,Inc,d,fl.end());
+   G.edge(F.top_node(), F.bottom_node());
+   Inc[F.bottom_node()] = 1;
+   Vector<Integer> fl(static_cast<Int>(Integer::fibonacci(d)));
+   calcEntry(F, G, Inc, d-1, fl.end());
    return fl;
 }
 
