@@ -102,7 +102,7 @@ UserFunctionTemplate4perl("# @category Producing a polytope from polytopes"
                           "# @param Polytope P2"
                           "# @option Bool no_labels Do not assign [[FACET_LABELS]]. default: 0"
                           "# @return Polytope"
-                          "# @example [prefer cdd] Let us look at the mapping polytope of the unit interval and the standard unimodular triangle."
+                          "# @example [prefer cdd] [require bundled:cdd] Let us look at the mapping polytope of the unit interval and the standard unimodular triangle."
                           "# > $I=simplex(1); $T=simplex(2); $Hom_IT=mapping_polytope($I,$T);"
                           "# The dimension equals (dim I + 1) * dim T."
                           "# > print $Hom_IT->DIM"
