@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -24,34 +25,34 @@ namespace polymake { namespace polytope {
 
 Matrix<double> points2metric_Euclidean(const Matrix<double> &V)
 { 
-  const int n=V.rows();
-  Matrix<double> dist(n,n);
+  const Int n = V.rows();
+  Matrix<double> dist(n, n);
 
-  for (int i=0; i<n; ++i)
-      for (int j=i; j<n; ++j)
-        dist(i,j)=dist(j,i)=sqrt(sqr(V.row(i)-V.row(j))); // Euclidean distance
+  for (Int i = 0; i < n; ++i)
+      for (Int j = i; j < n; ++j)
+        dist(i,j) = dist(j,i) = sqrt(sqr(V.row(i)-V.row(j))); // Euclidean distance
   return dist;
 }
 
 template <typename Scalar>
 Matrix<Scalar> points2metric_max(const Matrix<Scalar> &V)
 {
-  const int n=V.rows();
+  const Int n = V.rows();
   Matrix<Scalar> dist(n,n);
-  for (int i=0; i<n; ++i)
-      for (int j=i; j<n; ++j)
-        dist(i,j)=dist(j,i)=accumulate(attach_operation(V.row(i)-V.row(j), operations::abs_value()), operations::max());
+  for (Int i = 0; i < n; ++i)
+      for (Int j = i; j < n; ++j)
+        dist(i,j) = dist(j,i) = accumulate(attach_operation(V.row(i)-V.row(j), operations::abs_value()), operations::max());
   return dist;
 }
 
 template <typename Scalar>
 Matrix<Scalar> points2metric_l1(const Matrix<Scalar> &V)
 {
-  const int n=V.rows();
-  Matrix<Scalar> dist(n,n);
-  for (int i=0; i<n; ++i)
-      for (int j=i; j<n; ++j)
-        dist(i,j)=dist(j,i)=accumulate(attach_operation(V.row(i)-V.row(j), operations::abs_value()), operations::add());
+  const Int n = V.rows();
+  Matrix<Scalar> dist(n, n);
+  for (Int i = 0; i < n; ++i)
+      for (Int j = i; j < n; ++j)
+        dist(i,j) = dist(j,i) = accumulate(attach_operation(V.row(i)-V.row(j), operations::abs_value()), operations::add());
   return dist;
 }
 
@@ -68,7 +69,7 @@ InsertEmbeddedRule("# @category Triangulations, subdivisions and volume"
                    "# @param Matrix points"
                    "# @option Bool max triggers the usage of the max-norm (exact computation)"
                    "# @option Bool l1 triggers the usage of the l1-norm (exact computation)"
-                   "# @return Matrix\n"
+                   "# @return Matrix"
                    "# @example"
                    "# > print points2metric(cube(2)->VERTICES, max=>1);"
                    "# | 0 2 2 2"
@@ -86,7 +87,7 @@ InsertEmbeddedRule("# @category Triangulations, subdivisions and volume"
                    "# If the option //max// or //l1// is set to true the max-norm or l1-norm is used instead (with exact computation)."
                    "# @param Polytope P"
                    "# @option Bool max triggers the usage of the max-norm (exact computation)"
-                   "# @return Matrix\n"
+                   "# @return Matrix"
                    "# @example"
                    "# > print poly2metric(cube(2), max=>1);"
                    "# | 0 2 2 2"
