@@ -39,7 +39,7 @@ UserFunction4perl("# @category Triangulations, subdivisions and volume"
                   "# @param Int k the number of vertices of the first simplex"
                   "# @param Int l the number of vertices of the second simplex"
                   "# @return Vector<Rational>"
-                  "# @example [application fan][prefer cdd]"
+                  "# @example [application fan][prefer cdd] [require bundled:cdd]"
                   "# The following creates the staircase triangulation of the product"
                   "# of the 2- and the 1-simplex."
                   "# > $w = staircase_weight(3,2);"
