@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -19,9 +20,9 @@
 
 namespace polymake { namespace topaz {
 
-Map< Array<int>,int > random_discrete_morse(const Lattice<BasicDecoration> orig_HD, UniformlyRandom<long> seed, const int strategy, const bool verbose, const int rounds, const Array<int> try_until_reached,  const Array<int> try_until_exception, std::string save_to_filename );
+Map<Array<Int>, Int> random_discrete_morse(const Lattice<BasicDecoration>& orig_HD, UniformlyRandom<long> seed, const Int strategy, const bool verbose, const Int rounds,
+                                           const Array<Int>& try_until_reached, const Array<Int>& try_until_exception, std::string save_to_filename);
 
-}}
+} }
 
 #endif // POLYMAKE_TOPAZ_RANDOM_DISCRETE_MORSE_H
-
