@@ -37,19 +37,24 @@ BigObject stanley_reisner(BigObject C)
      gens[k] = Polynomial<Rational, Int>(1, same_element_sparse_vector<Int>(non_faces[k], n_vertices));
   }
 
-  BigObject I("ideal::Ideal");
-  I.take("GENERATORS") << gens;
-  I.take("MONOMIAL") << true;
-  I.take("N_VARIABLES") << n_vertices;
+  BigObject I("ideal::Ideal",
+              "GENERATORS", gens,
+              "MONOMIAL", true,
+              "N_VARIABLES", n_vertices);
   I.set_description() << "Stanley-Reisner ideal of " << C.name();
-
   return I;
 }
 
 UserFunction4perl("# @category Other"
                   "# Creates the __Stanley-Reisner ideal__ of a simplicial complex."
                   "# @param  SimplicialComplex complex"
-                  "# @return ideal::Ideal",
+                  "# @return ideal::Ideal"
+                  "# @example"
+                  "# > $s = new SimplicialComplex(INPUT_FACES=>[[0, 1], [0, 2], [1, 2], [2, 3]]);"
+                  "# > $i = stanley_reisner($s);"
+                  "# > print $i -> GENERATORS;"
+                  "# | x_0*x_1*x_2 x_0*x_3 x_1*x_3",
+
                   &stanley_reisner, "stanley_reisner(SimplicialComplex)");
 } }
 
