@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -34,7 +35,7 @@ extern "C" {
 
 namespace polymake { namespace polytope { namespace cdd_interface {
 
-template <typename Coord> struct traits;
+template <typename Scalar> struct traits;
 
 // this double indirection is needed for the macros to work!
 #define CDDRESOLVE(a)      CDDRESOLVE_REAL(a)
@@ -85,17 +86,17 @@ struct traits<double> {
 };
 #endif
 
-template <typename Coord>
+template <typename Scalar>
 class vector_output {
 public:
-   typedef traits<Coord> traits_t;
+   typedef traits<Scalar> traits_t;
 
-   vector_output(mytype* start_arg, int sz_arg)
+   vector_output(mytype* start_arg, Int sz_arg)
       : start(start_arg)
       , sz(sz_arg) {}
 
    typedef std::input_iterator_tag container_category;
-   typedef Coord value_type;
+   typedef Scalar value_type;
    typedef value_type reference;
    typedef value_type const_reference;
    typedef pm::unary_transform_iterator<pm::pointer2iterator_t<mytype*>, typename traits_t::getter> iterator;
@@ -106,21 +107,21 @@ public:
 
 private:
    mytype* start;
-   int sz;
+   Int sz;
 };
 
-template <typename Coord>
+template <typename Scalar>
 class matrix_output_rows_iterator {
 public:
    typedef std::input_iterator_tag iterator_category;
-   typedef vector_output<Coord> value_type;
+   typedef vector_output<Scalar> value_type;
    typedef value_type reference;
    typedef void pointer;
    typedef ptrdiff_t difference_type;
 
-   typedef ListMatrix<Vector<Coord>> lin_matrix_t;
+   typedef ListMatrix<Vector<Scalar>> lin_matrix_t;
 
-   matrix_output_rows_iterator(mytype** start, int n_rows, int n_cols_arg,
+   matrix_output_rows_iterator(mytype** start, Int n_rows, Int n_cols_arg,
                                dd_rowset lin_set_arg, lin_matrix_t& lin_out_arg)
       : cur(start)
       , end(start+n_rows)
@@ -150,7 +151,7 @@ private:
    void valid_position()
    {
       while (!at_end() && set_member(row_index, lin_set)) {
-         lin_out /= Vector<Coord>(n_cols, typename value_type::iterator(*cur));
+         lin_out /= Vector<Scalar>(n_cols, typename value_type::iterator(*cur));
          ++cur;
          ++row_index;
       }
@@ -158,82 +159,86 @@ private:
 
    mytype** cur;
    mytype** end;
-   int n_cols;
-   int row_index;
+   Int n_cols;
+   Int row_index;
    dd_rowset lin_set;
    lin_matrix_t& lin_out;
 };
 
 
-template <typename Coord> class cdd_polyhedron;
-template <typename Coord> class cdd_lp;
-template <typename Coord> class cdd_lp_sol;
-template <typename Coord> class cdd_matrix;
+template <typename Scalar> class cdd_polyhedron;
+template <typename Scalar> class cdd_lp;
+template <typename Scalar> class cdd_lp_sol;
+template <typename Scalar> class cdd_matrix;
 
-template <typename Coord>
-class cdd_vector : public traits<Coord> {
-   typedef traits<Coord> traits_t;
+template <typename Scalar>
+class cdd_vector : public traits<Scalar> {
+   typedef traits<Scalar> traits_t;
 
-   friend class cdd_matrix<Coord>;
+   friend class cdd_matrix<Scalar>;
 public:
-   explicit cdd_vector(int dim_arg) : dim(dim_arg)
+   explicit cdd_vector(Int dim_arg) : dim(dim_arg)
    {
       CDDRESOLVE(InitializeArow)(dim, &ptr);
    }
 
    ~cdd_vector() { CDDRESOLVE(FreeArow)(dim, ptr); }
 
-   Vector<Coord> get(int start_at=0) const
+   Vector<Scalar> get(Int start_at = 0) const
    {
-      Vector<Coord> result(dim-start_at, typename vector_output<Coord>::iterator(ptr+start_at));
+      Vector<Scalar> result(dim-start_at, typename vector_output<Scalar>::iterator(ptr+start_at));
       for (mytype *cur=ptr+start_at, *end=ptr+dim; cur != end; ++cur)
          CDDRESOLVE(init)(*cur);
       return result;
    }
 
 private:
-   int dim;
+   Int dim;
    CDDRESOLVE(Arow) ptr;
 };
 
-template <typename Coord>
-class cdd_matrix : public traits<Coord> {
-   typedef traits<Coord> traits_t;
+template <typename Scalar>
+class cdd_matrix : public traits<Scalar> {
+   using traits_t = traits<Scalar>;
 
-   friend class cdd_polyhedron<Coord>;
-   friend class cdd_lp<Coord>;
-   friend class solver<Coord>;
+   friend class cdd_polyhedron<Scalar>;
+   friend class cdd_lp<Scalar>;
+   friend class ConvexHullSolver<Scalar>;
+   friend class LP_Solver<Scalar>;
 public:
    // build from points and rays alone
-   cdd_matrix(const Matrix<Coord>& P);
+   cdd_matrix(const Matrix<Scalar>& P);
+
    // build from inequalities and equations or rays and lineality
-   // primal <-> build from inequalities and equations ( seems to be the definition ... )
-   cdd_matrix(const Matrix<Coord>& I, const Matrix<Coord>& E, const bool primal = true);
+   cdd_matrix(const Matrix<Scalar>& I, const Matrix<Scalar>& E, const representation source_rep);
+
    // build from computed convex hull
-   cdd_matrix(const cdd_polyhedron<Coord>&, bool primal);
+   cdd_matrix(const cdd_polyhedron<Scalar>&, const representation target_rep);
 
    ~cdd_matrix() { CDDRESOLVE(FreeMatrix)(ptr); }
 
-   void add_objective(const Vector<Coord>& obj, bool maximize);
+   void add_objective(const Vector<Scalar>& obj, bool maximize);
 
-   typename solver<Coord>::matrix_pair representation_conversion(const bool isCone = false, const bool primal = true) const;
+   convex_hull_result<Scalar> representation_conversion(const bool isCone, const representation target_rep) const;
 
-   ListMatrix< Vector<Coord> > vertex_normals(Bitset& Vertices);
+   ListMatrix< Vector<Scalar> > vertex_normals(Bitset& Vertices);
 
-   void canonicalize(Bitset& Pt, Bitset& Lin);
+   std::pair<Bitset, Set<Int>> canonicalize();
 
    void canonicalize_lineality(Bitset& Lin);
 
 private:
    CDDRESOLVE(MatrixPtr) ptr;
+   const Int num_rays_ineqs;
 };
 
-template <typename Coord>
+template <typename Scalar>
 class cdd_polyhedron {
-   friend class cdd_matrix<Coord>;
-   friend class solver<Coord>;
+   friend class cdd_matrix<Scalar>;
+   friend class ConvexHullSolver<Scalar>;
 public:
-   cdd_polyhedron(const cdd_matrix<Coord>& M) : ptr(CDDRESOLVE(DDMatrix2Poly)(M.ptr, &err)) {}
+   cdd_polyhedron(const cdd_matrix<Scalar>& M)
+      : ptr(CDDRESOLVE(DDMatrix2Poly)(M.ptr, &err)) {}
    ~cdd_polyhedron() { CDDRESOLVE(FreePolyhedra)(ptr); }
    void verify();
 protected:
@@ -241,29 +246,30 @@ protected:
    CDDRESOLVE(ErrorType) err;
 };
 
-template <typename Coord>
-class cdd_lp : public traits<Coord> {
-   typedef traits<Coord> traits_t;
-   friend class cdd_lp_sol<Coord>;
+template <typename Scalar>
+class cdd_lp : public traits<Scalar> {
+   typedef traits<Scalar> traits_t;
+   friend class cdd_lp_sol<Scalar>;
 public:
-   cdd_lp(const cdd_matrix<Coord>& M) : ptr(CDDRESOLVE(Matrix2LP)(M.ptr, &err)) {}
+   cdd_lp(const cdd_matrix<Scalar>& M)
+      : ptr(CDDRESOLVE(Matrix2LP)(M.ptr, &err)) {}
    ~cdd_lp() { CDDRESOLVE(FreeLPData)(ptr); }
 
-   Vector<Coord> optimal_vertex() const;
+   Vector<Scalar> optimal_vertex() const;
 protected:
    CDDRESOLVE(LPPtr) ptr;
    CDDRESOLVE(ErrorType) err;
    CDDRESOLVE(LPSolutionPtr) get_solution();
 };
 
-template <typename Coord>
+template <typename Scalar>
 class cdd_lp_sol {
 public:
-   void verify();
-   cdd_lp_sol(cdd_lp<Coord>& L) : ptr(L.get_solution()) {}
+   cdd_lp_sol(cdd_lp<Scalar>& L) : ptr(L.get_solution()) {}
    ~cdd_lp_sol() { CDDRESOLVE(FreeLPSolution)(ptr); }
 
-   Coord optimal_value() const;
+   Scalar optimal_value() const;
+   LP_status get_status(bool throw_when_bad_dual) const;
 protected:
    CDDRESOLVE(LPSolutionPtr) ptr;
 };
@@ -274,9 +280,9 @@ class cdd_bitset_iterator {
    friend class cdd_bitset;
 public:
    typedef std::forward_iterator_tag iterator_category;
-   typedef int value_type;
-   typedef const int& reference;
-   typedef const int* pointer;
+   typedef Int value_type;
+   typedef const Int& reference;
+   typedef const Int* pointer;
    typedef ptrdiff_t difference_type;
 
    typedef cdd_bitset_iterator iterator;
@@ -327,24 +333,24 @@ protected:
    }
 
    set_type s;
-   int cur, end;
+   Int cur, end;
    unsigned long bit;
 };
 
-class cdd_bitset : public GenericSet<cdd_bitset, int, pm::operations::cmp> {
+class cdd_bitset : public GenericSet<cdd_bitset, Int, pm::operations::cmp> {
    template <typename> friend class cdd_matrix;
 public:
    // CAUTION: sets are initialized within cddlib functions.
-   cdd_bitset() : ptr(0) {}
+   cdd_bitset() : ptr(nullptr) {}
    ~cdd_bitset() { set_free(ptr); }
 
-   int size() const { return set_card(ptr); }
+   Int size() const { return set_card(ptr); }
    bool empty() const { return size()==0; }
-   int dim() const { return set_groundsize(ptr); }
+   Int dim() const { return set_groundsize(ptr); }
 
-   typedef int value_type;
-   typedef int reference;
-   typedef int const_reference;
+   typedef Int value_type;
+   typedef Int reference;
+   typedef Int const_reference;
    typedef cdd_bitset_iterator iterator;
    typedef iterator const_iterator;
 
@@ -365,11 +371,11 @@ struct check_iterator_feature<polymake::polytope::cdd_interface::cdd_bitset_iter
 template <>
 struct check_container_feature<polymake::polytope::cdd_interface::cdd_bitset, sparse_compatible> : std::true_type {};
 
-template <typename Coord>
-struct check_iterator_feature<polymake::polytope::cdd_interface::matrix_output_rows_iterator<Coord>, end_sensitive> : std::true_type {};
+template <typename Scalar>
+struct check_iterator_feature<polymake::polytope::cdd_interface::matrix_output_rows_iterator<Scalar>, end_sensitive> : std::true_type {};
 
-template <typename Coord>
-struct spec_object_traits<polymake::polytope::cdd_interface::vector_output<Coord>> : spec_object_traits<is_container> {};
+template <typename Scalar>
+struct spec_object_traits<polymake::polytope::cdd_interface::vector_output<Scalar>> : spec_object_traits<is_container> {};
 
 }
 namespace polymake { namespace polytope { namespace cdd_interface {
@@ -377,13 +383,14 @@ namespace polymake { namespace polytope { namespace cdd_interface {
 // FIXME: method currently used for RAY_SEPARATORS/VERTEX_NORMALS from RAYS
 //        for this computation LINEALITY_SPACE is not needed
 // should not be used for INEQUALITES (set representation type)
-template <typename Coord>
-cdd_matrix<Coord>::cdd_matrix(const Matrix<Coord>& P)
+template <typename Scalar>
+cdd_matrix<Scalar>::cdd_matrix(const Matrix<Scalar>& P)
    : ptr(CDDRESOLVE(CreateMatrix)(P.rows(), P.cols()))
+   , num_rays_ineqs(P.rows())
 {
    // get size of the input matrix
-   int m = P.rows();
-   int n = P.cols();
+   Int m = P.rows();
+   Int n = P.cols();
 
    ptr->representation = CDDRESOLVE(Generator);    // Input type: points
    ptr->numbtype = traits_t::number_type;
@@ -396,17 +403,17 @@ cdd_matrix<Coord>::cdd_matrix(const Matrix<Coord>& P)
       for (;  c!=cend;  ++c, ++p)
          traits_t::store(c, p);
    }
-
 }
 
-template <typename Coord>
-cdd_matrix<Coord>::cdd_matrix(const Matrix<Coord>& I, const Matrix<Coord>& E, const bool primal)
-   : ptr(CDDRESOLVE(CreateMatrix)(I.rows() + E.rows(),  ( I.cols() | E.cols() ) ) ) {
-
+template <typename Scalar>
+cdd_matrix<Scalar>::cdd_matrix(const Matrix<Scalar>& I, const Matrix<Scalar>& E, const representation source_rep)
+   : ptr(CDDRESOLVE(CreateMatrix)(I.rows() + E.rows(), I.cols() ? I.cols() : E.cols()))
+   , num_rays_ineqs(I.rows())
+{
    // get size of the input matrix
-   int mi = I.rows();
-   int me = E.rows();
-   int n  = I.cols() | E.cols();
+   Int mi = I.rows();
+   Int me = E.rows();
+   Int n  = I.cols() ? I.cols() : E.cols();
 
    // avoid segfault in some cdd versions for degenerate cases
    if (n == 0) {
@@ -414,7 +421,7 @@ cdd_matrix<Coord>::cdd_matrix(const Matrix<Coord>& I, const Matrix<Coord>& E, co
       throw std::runtime_error("cdd_interface - cannot properly handle ambient dimension 0");
    }
 
-   if ( primal )
+   if (source_rep == representation::H)
       ptr->representation = CDDRESOLVE(Inequality);   // Input type: inequalities
    else
       ptr->representation = CDDRESOLVE(Generator);    // Input type: points
@@ -440,8 +447,8 @@ cdd_matrix<Coord>::cdd_matrix(const Matrix<Coord>& I, const Matrix<Coord>& E, co
    }
 }
 
-template <typename Coord>
-void cdd_matrix<Coord>::add_objective(const Vector<Coord>& obj, bool maximize)
+template <typename Scalar>
+void cdd_matrix<Scalar>::add_objective(const Vector<Scalar>& obj, bool maximize)
 {
    auto o=obj.begin();
    for (mytype *r=ptr->rowvec, *rend=r+obj.size();  r!=rend;  ++r, ++o)
@@ -449,8 +456,8 @@ void cdd_matrix<Coord>::add_objective(const Vector<Coord>& obj, bool maximize)
    ptr->objective= maximize ? CDDRESOLVE(LPmax) : CDDRESOLVE(LPmin);
 }
 
-template <typename Coord>
-void cdd_polyhedron<Coord>::verify()
+template <typename Scalar>
+void cdd_polyhedron<Scalar>::verify()
 {
    if (err != CDDRESOLVE(NoError)) {
       std::ostringstream err_msg;
@@ -459,8 +466,8 @@ void cdd_polyhedron<Coord>::verify()
    }
 }
 
-template <typename Coord>
-CDDRESOLVE(LPSolutionPtr) cdd_lp<Coord>::get_solution()
+template <typename Scalar>
+CDDRESOLVE(LPSolutionPtr) cdd_lp<Scalar>::get_solution()
 {
    if (err != CDDRESOLVE(NoError)) {
       std::ostringstream err_msg;
@@ -477,27 +484,27 @@ CDDRESOLVE(LPSolutionPtr) cdd_lp<Coord>::get_solution()
    return CDDRESOLVE(CopyLPSolution)(ptr);
 }
 
-template <typename Coord>
-cdd_matrix<Coord>::cdd_matrix(const cdd_polyhedron<Coord>& P, bool primal)
-   : ptr(primal ? CDDRESOLVE(CopyInequalities)(P.ptr) : CDDRESOLVE(CopyGenerators)(P.ptr)) { }
+template <typename Scalar>
+cdd_matrix<Scalar>::cdd_matrix(const cdd_polyhedron<Scalar>& P, const representation target_rep)
+   : ptr(target_rep == representation::H ? CDDRESOLVE(CopyInequalities)(P.ptr) : CDDRESOLVE(CopyGenerators)(P.ptr))
+   , num_rays_ineqs(0) { }
 
 // extracts the dual description from a cdd matrix
 // and makes some adjustements for polymake needs
-// primal <-> input representation by inequalities/equations
-template <typename Coord>
-typename solver<Coord>::matrix_pair
-cdd_matrix<Coord>::representation_conversion(const bool isCone, const bool primal ) const
+template <typename Scalar>
+convex_hull_result<Scalar>
+cdd_matrix<Scalar>::representation_conversion(const bool isCone, const representation target_rep) const
 {
    const CDDRESOLVE(rowrange) m = ptr->rowsize;
    const CDDRESOLVE(colrange) n = ptr->colsize;
    const long linsize = set_card(ptr->linset);
 
-   if (primal && m<=0) throw infeasible();
+   if (target_rep == representation::V && m<=0) throw infeasible();
 
-   ListMatrix<Vector<Coord>> Lin(0, n);
-   Matrix<Coord> Pt(m-linsize, n, matrix_output_rows_iterator<Coord>(ptr->matrix, m, n, ptr->linset, Lin));
+   ListMatrix<Vector<Scalar>> Lin(0, n);
+   Matrix<Scalar> Pt(m-linsize, n, matrix_output_rows_iterator<Scalar>(ptr->matrix, m, n, ptr->linset, Lin));
 
-   if (primal) {
+   if (target_rep == representation::V) {
       // for a 0-dimensional cone cdd returns the origin as a vertex
       // we have to remove this in our interpretation
       if (isCone && !linsize && Pt.rows()==1 && Pt(0,0)==1)
@@ -506,22 +513,22 @@ cdd_matrix<Coord>::representation_conversion(const bool isCone, const bool prima
       // in the case of a homogeneous cone, the cddlib omits the origin point
       // in the case of a cone we don't want to add this!
       if (!linsize && is_zero(Pt.col(0)) && !isCone)
-         Pt /= unit_vector<Coord>(Pt.cols(), 0);
+         Pt /= unit_vector<Scalar>(Pt.cols(), 0);
    }
 
-   return typename solver<Coord>::matrix_pair(Pt, Matrix<Coord>(linsize, n, operations::move(), entire(rows(Lin))));
+   return { Pt, Matrix<Scalar>(linsize, n, operations::move(), entire(rows(Lin))) };
 }
 
 
-template <typename Coord>
-ListMatrix< Vector<Coord> >
-cdd_matrix<Coord>::vertex_normals(Bitset& Vertices)
+template <typename Scalar>
+ListMatrix< Vector<Scalar> >
+cdd_matrix<Scalar>::vertex_normals(Bitset& Vertices)
 {
-   ListMatrix< Vector<Coord> > VN;
+   ListMatrix< Vector<Scalar> > VN(0, ptr->colsize+1);
    auto vn_front=rows(VN).begin();
-   cdd_vector<Coord> cert(ptr->colsize+1);
+   cdd_vector<Scalar> cert(ptr->colsize+1);
    CDDRESOLVE(ErrorType) err;
-   for (int i=ptr->rowsize; i>=1; --i) {
+   for (Int i = ptr->rowsize; i >= 1; --i) {
       const bool is_redundant=CDDRESOLVE(Redundant)(ptr, i, cert.ptr, &err);
       if (err != CDDRESOLVE(NoError)) {
          std::ostringstream err_msg;
@@ -532,7 +539,7 @@ cdd_matrix<Coord>::vertex_normals(Bitset& Vertices)
          CDDRESOLVE(MatrixRowRemove)(&ptr, i);
       } else {
          Vertices += i-1;
-         Vector<Coord> vertex_normal=cert.get(1);
+         Vector<Scalar> vertex_normal=cert.get(1);
          //  we redefined vertex normals to be affine functionals
          //  vertex_normal[0]=0;
          // vertex_normal.negate();
@@ -545,9 +552,9 @@ cdd_matrix<Coord>::vertex_normals(Bitset& Vertices)
 }
 
 
-template <typename Coord>
-void
-cdd_matrix<Coord>::canonicalize(Bitset& Pt, Bitset& Lin) {
+template <typename Scalar>
+std::pair<Bitset, Set<Int>> cdd_matrix<Scalar>::canonicalize()
+{
    cdd_bitset impl_linset, redset;
    CDDRESOLVE(rowindex) newpos;
    CDDRESOLVE(ErrorType) err;
@@ -561,22 +568,26 @@ cdd_matrix<Coord>::canonicalize(Bitset& Pt, Bitset& Lin) {
       throw std::runtime_error(err_msg.str());
    }
 
+   std::pair<Bitset, Set<Int>> result{ Bitset(num_rays_ineqs), Set<Int>() };
    const long linsize = set_card(ptr->linset);
-
-   for (int i = 1; i <= m; ++i )
-      if ( newpos[i] > 0 ) {
-         if ( newpos[i] <= linsize )
-            Lin += i-1;
+   for (Int i = 1; i <= m; ++i) {
+      if (newpos[i] > 0) {
+         if (newpos[i] <= linsize)
+            result.second += i-1;
          else
-            Pt += i-1;
+            result.first += i-1;
       }
+   }
+
    free(newpos);
+   return result;
 }
 
 
-template <typename Coord>
+template <typename Scalar>
 void
-cdd_matrix<Coord>::canonicalize_lineality(Bitset& Lin) {
+cdd_matrix<Scalar>::canonicalize_lineality(Bitset& Lin)
+{
    cdd_bitset impl_linset;
    CDDRESOLVE(rowindex) newpos;
    CDDRESOLVE(ErrorType) err;
@@ -592,137 +603,144 @@ cdd_matrix<Coord>::canonicalize_lineality(Bitset& Lin) {
 
    const long linsize = set_card(ptr->linset);
 
-   for (int i = 1; i <= m; ++i )
+   for (Int i = 1; i <= m; ++i )
       if ( newpos[i] > 0 && newpos[i] <= linsize )
          Lin += i-1;
 
    free(newpos);
 }
 
-template <typename Coord>
-void cdd_lp_sol<Coord>::verify()
+template <typename Scalar>
+LP_status cdd_lp_sol<Scalar>::get_status(bool throw_when_bad_dual) const
 {
    switch (ptr->LPS) {
    case CDDRESOLVE(Optimal):
-       break;
-   case CDDRESOLVE(StrucInconsistent):   // if the problem is inconsistent then mark that there is no valid point
+      return LP_status::valid;
+   case CDDRESOLVE(StrucInconsistent):
    case CDDRESOLVE(Inconsistent):
-      throw infeasible();
-   case CDDRESOLVE(Unbounded):      // if the problem is unbounded then mark that there is no optimal solution
-      throw unbounded();
-   case CDDRESOLVE(StrucDualInconsistent):  // if the dual problem is either unbounded or
-   case CDDRESOLVE(DualUnbounded):          // inconsistent we don't know whether the primal
-   case CDDRESOLVE(DualInconsistent):       // is inconsistent or unbounded
-      throw baddual("cannot handle lp solution: problem is either inconsistent or unbounded");
-   default:  // all other cases are handled here ....
+      return LP_status::infeasible;
+   case CDDRESOLVE(Unbounded):
+      return LP_status::unbounded;
+   case CDDRESOLVE(StrucDualInconsistent):
+   case CDDRESOLVE(DualInconsistent):
+   case CDDRESOLVE(DualUnbounded):
+      if (throw_when_bad_dual)
+         throw infeasible();
+      return LP_status::infeasible;
+   default:
       std::ostringstream err_msg;
       err_msg << "cannot handle lp solution: cdd returned: " << ptr->LPS;
       throw std::runtime_error(err_msg.str());
    }
 }
 
-template <typename Coord>
-Vector<Coord> cdd_lp<Coord>::optimal_vertex() const
+template <typename Scalar>
+Vector<Scalar> cdd_lp<Scalar>::optimal_vertex() const
 {
-   return Vector<Coord>(ptr->d, typename vector_output<Coord>::iterator(ptr->sol));
+   return Vector<Scalar>(ptr->d, typename vector_output<Scalar>::iterator(ptr->sol));
 }
 
 // end of cdd classes
-//  implementation of solver methods
+//  implementation of ConvexHullSolver methods
 
-// count how many solver instances are active to make sure that they are initialized and freed correctly
-// the variable lives in cdd_interface.cc
-extern int solver_count;
-
-// we only use the dd_ variant as this allocates both the dd_ and ddf_ global variables
-// also to make sure there are no problems when only some are freed by the ddf_free function
-template <typename Coord>
-solver<Coord>::solver()
+template <typename Scalar>
+convex_hull_result<Scalar>
+ConvexHullSolver<Scalar>::enumerate_facets(const Matrix<Scalar>& Points, const Matrix<Scalar>& Lineality, const bool isCone) const
 {
-   if (solver_count++ == 0) {
-      dd_set_global_constants();
-      if (int(perl::get_custom("$polytope::verbose_cdd")) > 0)
-         dd_debug = dd_TRUE;
-      else
-         dd_debug = dd_FALSE;
+   if(Points.rows() == 0 && Lineality.rows() == 0){
+      // We deal with the trivial case here, since cdd fails for being called with two empty matrices.
+      return convex_hull_result<Scalar>(Matrix<Scalar>(0,Points.cols()), Matrix<Scalar>(unit_matrix<Scalar>(Points.cols())));
    }
-}
-
-template <typename Coord>
-solver<Coord>::~solver()
-{
-   if (--solver_count == 0) {
-      dd_free_global_constants();
-      dd_debug = dd_FALSE;
-   }
-}
-
-// this and the following function are identical
-// we still need both for consistency with lrs
-template <typename Coord>
-typename solver<Coord>::matrix_pair
-solver<Coord>::enumerate_facets(const Matrix<Coord>& Points, const Matrix<Coord>& Lineality, const bool isCone, const bool primal)
-{
-   cdd_matrix<Coord> IN(Points, Lineality, primal);
-   cdd_polyhedron<Coord> P(IN);
+   dd_debug = verbose ? dd_TRUE : dd_FALSE;
+   cdd_matrix<Scalar> IN(Points, Lineality, representation::V);
+   cdd_polyhedron<Scalar> P(IN);
+   dd_debug = dd_FALSE;
    P.verify();
-   return cdd_matrix<Coord>(P, !primal).representation_conversion(isCone,primal);
+   return cdd_matrix<Scalar>(P, representation::H).representation_conversion(isCone, representation::H);
 }
 
-template <typename Coord>
-typename solver<Coord>::matrix_pair
-solver<Coord>::enumerate_vertices(const Matrix<Coord>& Inequalities, const Matrix<Coord>& Equations, const bool isCone, const bool primal )
+template <typename Scalar>
+convex_hull_result<Scalar>
+ConvexHullSolver<Scalar>::enumerate_vertices(const Matrix<Scalar>& Inequalities, const Matrix<Scalar>& Equations, const bool isCone) const
 {
-   cdd_matrix<Coord> IN(Inequalities, Equations, primal);
-   cdd_polyhedron<Coord> P(IN);
+   dd_debug = verbose ? dd_TRUE : dd_FALSE;
+   cdd_matrix<Scalar> IN(Inequalities, Equations, representation::H);
+   cdd_polyhedron<Scalar> P(IN);
+   dd_debug = dd_FALSE;
    P.verify();
-   return cdd_matrix<Coord>(P, !primal).representation_conversion(isCone,primal);
+   return cdd_matrix<Scalar>(P, representation::V).representation_conversion(isCone, representation::V);
 }
 
-template <typename Coord>
-typename solver<Coord>::non_redundant_canonical
-solver<Coord>::canonicalize(const Matrix<Coord>& Pt, const Matrix<Coord>& Lin, bool primal)
+template <typename Scalar>
+std::pair<Bitset, Set<Int>>
+ConvexHullSolver<Scalar>::get_non_redundant_points(const Matrix<Scalar>& Pt, const Matrix<Scalar>& Lin, bool /* isCone */) const
 {
-   cdd_matrix<Coord> IN(Pt, Lin, false);  // in some cases cdd does not return the facet x_0>=0 for the primal reduction
-                                          // so we always use the dual reduction
-                                          // FIXME this has to be checked carefully
-   Bitset red_Pt(Pt.rows());
-   Bitset red_Lin(Pt.rows());
-   IN.canonicalize(red_Pt,red_Lin);
-   return non_redundant_canonical(red_Pt,red_Lin);
+   cdd_matrix<Scalar> IN(Pt, Lin, representation::V);
+   // in some cases cdd does not return the facet x_0>=0 for the primal reduction
+   // so we always use the dual reduction
+   // FIXME this has to be checked carefully
+   return IN.canonicalize();
 }
 
-template <typename Coord>
+template <typename Scalar>
+std::pair<Bitset, Set<Int>>
+ConvexHullSolver<Scalar>::get_non_redundant_inequalities(const Matrix<Scalar>& Ineq, const Matrix<Scalar>& Eq, bool /* isCone */) const
+{
+   cdd_matrix<Scalar> IN(Ineq, Eq, representation::H);
+   return IN.canonicalize();
+}
+
+template <typename Scalar>
 Bitset
-solver<Coord>::canonicalize_lineality(const Matrix<Coord>& Pt, const Matrix<Coord>& Lin, bool primal)
+ConvexHullSolver<Scalar>::canonicalize_lineality(const Matrix<Scalar>& Pt, const Matrix<Scalar>& Lin, const representation source_rep)
 {
-   cdd_matrix<Coord> IN(Pt, Lin, primal);
+   cdd_matrix<Scalar> IN(Pt, Lin, source_rep);
    Bitset red_Lin(Pt.rows());
    IN.canonicalize_lineality(red_Lin);
    return red_Lin;
 }
 
 // FIXME Why is there no dual version of this?
-template <typename Coord>
-typename solver<Coord>::non_redundant
-solver<Coord>::find_vertices_among_points(const Matrix<Coord>& Points)
+template <typename Scalar>
+typename ConvexHullSolver<Scalar>::non_redundant
+ConvexHullSolver<Scalar>::find_vertices_among_points(const Matrix<Scalar>& Points)
 {
-   cdd_matrix<Coord> IN(Points);
+   cdd_matrix<Scalar> IN(Points);
    Bitset Vertices(Points.rows());
    return non_redundant(Vertices, IN.vertex_normals(Vertices));
 }
 
-template <typename Coord>
-typename solver<Coord>::lp_solution
-solver<Coord>::solve_lp(const Matrix<Coord>& Inequalities, const Matrix<Coord>& Equations,
-                        const Vector<Coord>& Objective, bool maximize)
+template <typename Scalar>
+LP_Solution<Scalar>
+LP_Solver<Scalar>::solve(const Matrix<Scalar>& Inequalities, const Matrix<Scalar>& Equations,
+                         const Vector<Scalar>& Objective, bool maximize, bool feasibility_known) const
 {
-   cdd_matrix<Coord> IN(Inequalities, Equations);
-   IN.add_objective(Objective, maximize);
-   cdd_lp<Coord> LP(IN);
-   cdd_lp_sol<Coord> Sol(LP);
-   Sol.verify();
-   return lp_solution(Sol.optimal_value(), LP.optimal_vertex());
+   LP_Solution<Scalar> result;
+   try {
+      cdd_matrix<Scalar> IN(Inequalities, Equations, representation::H);
+      IN.add_objective(Objective, maximize);
+      cdd_lp<Scalar> LP(IN);
+      cdd_lp_sol<Scalar> Sol(LP);
+      result.status = Sol.get_status(true);
+      if (result.status == LP_status::valid) {
+         result.objective_value = Sol.optimal_value();
+         result.solution = LP.optimal_vertex();
+      }
+   }
+   catch (const infeasible&) {
+      // could not figure out whether the problem is infeasible or unbounded, retry with a trivial objective function
+      if (feasibility_known) {
+         result.status = Inequalities.rows() == 0 ? LP_status::infeasible : LP_status::unbounded;
+      } else {
+         cdd_matrix<Scalar> IN(Inequalities, Equations, representation::H);
+         const Vector<Scalar> unit = unit_vector<Scalar>(Inequalities.cols(), 0);
+         IN.add_objective(unit, true);
+         cdd_lp<Scalar> LP(IN);
+         cdd_lp_sol<Scalar> Sol(LP);
+         result.status = Sol.get_status(false) == LP_status::infeasible ? LP_status::infeasible : LP_status::unbounded;
+      }
+   }
+   return result;
 }
 
 } } }
