@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,7 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#include <Singular/libsingular.h>
+#include "polymake/ideal/internal/singularInclude.h"
 
 #include "polymake/client.h"
 #include "polymake/Matrix.h"
@@ -27,15 +28,15 @@ namespace polymake {
 namespace ideal {
 namespace singular {
 
-perl::ListReturn singular_get_var(const std::string varname){
+ListReturn singular_get_var(const std::string varname){
    init_singular();
    int nest = myynest;
    myynest = 1;
    idhdl var = ggetid(omStrDup(varname.c_str()));
    myynest = nest;
-   if (var == NULL)
-      throw std::runtime_error("singular_get_int: could not find variable '"+varname+"'");
-   perl::ListReturn res;
+   if (var == nullptr)
+      throw std::runtime_error("singular_get_var: could not find variable '"+varname+"'");
+   ListReturn res;
    
    switch(var->typ){
       case INT_CMD:
@@ -49,7 +50,7 @@ perl::ListReturn singular_get_var(const std::string varname){
             const intvec *iv = (intvec*) IDDATA(var);
             Vector<Integer> pmvec(iv->length());
             int i = 0;
-            for(Entire<Vector<Integer> >::iterator it = entire(pmvec); !it.at_end(); ++it, ++i){
+            for (auto it = entire(pmvec); !it.at_end(); ++it, ++i) {
                *it = (*iv)[i];
             }
             res << pmvec;
@@ -69,7 +70,7 @@ perl::ListReturn singular_get_var(const std::string varname){
       case POLY_CMD:
          {
             const poly q = (poly) IDDATA(var);
-            std::pair<std::vector<Rational>, ListMatrix<Vector<int>>> decomposed = convert_poly_to_vector_and_matrix(q);
+            std::pair<std::vector<Rational>, ListMatrix<Vector<Int>>> decomposed = convert_poly_to_vector_and_matrix(q);
             Polynomial<Rational> result(decomposed.first, decomposed.second);
             res << result;
             break;
@@ -87,11 +88,11 @@ perl::ListReturn singular_get_var(const std::string varname){
 void singular_eval(const std::string cmd){
    init_singular();
    int nest = myynest;
-   if (currentVoice == NULL)
-      currentVoice=feInitStdin(NULL);
+   if (currentVoice == nullptr)
+      currentVoice=feInitStdin(nullptr);
    myynest = 1;
    // the return is needed to stop the interpreter
-   int err=iiAllStart(NULL,omStrDup((cmd+";return();").c_str()),BT_proc,0);
+   int err=iiAllStart(nullptr, omStrDup((cmd+";return();").c_str()),BT_proc,0);
    myynest = nest;
    if (err) {
       errorreported = 0; // reset error handling
@@ -102,19 +103,6 @@ void singular_eval(const std::string cmd){
 }
 
 
-long singular_get_int(const std::string varname){
-   init_singular();
-   int nest = myynest;
-   myynest = 1;
-   idhdl var = ggetid(omStrDup(varname.c_str()));
-   myynest = nest;
-   if (var == NULL)
-      throw std::runtime_error("singular_get_int: could not find variable '"+varname+"'");
-   if (var->typ != INT_CMD)
-      throw std::runtime_error("singular_get_int: variable '"+varname+"' not an int");
-   return (long) IDDATA(var);
-}
-
 } // end namespace singular
 
 UserFunction4perl("# @category Singular interface"
@@ -122,11 +110,6 @@ UserFunction4perl("# @category Singular interface"
                   "# @param String s",
                   &singular::singular_eval, "singular_eval($)");
 
-UserFunction4perl("# @category Singular interface"
-                  "# Retrieves an int variable from 'Singular'"
-                  "# @param String s",
-                  &singular::singular_get_int, "singular_get_int($)");
-
 UserFunction4perl("# @category Singular interface"
                   "# Retrieves a variable from 'Singular'"
                   "# @param String s variable name"
