@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -100,9 +101,6 @@ namespace pm {
       ElementType(), which is 0 for most numerical types) are not stored, but
       implicitly encoded by the gaps in the key set.  It is based on an AVL
       tree.
-    
-    - FixedVector is a built-in array of a fixed dimension decorated with the
-      common vector interface.
 
     @subsection matrix_sec Matrix Types
 
