@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -32,13 +33,13 @@ template <typename E>
 class Matrix_base {
 protected:
    struct dim_t {
-      int dimr, dimc;
+      Int dimr, dimc;
 
       dim_t() : dimr(0), dimc(0) {}
 
-      dim_t(int r, int c) : dimr(r), dimc(c) {
+      dim_t(Int r, Int c) : dimr(r), dimc(c) {
          if (POLYMAKE_DEBUG) {
-            if (dimr<0 || dimc<0)
+            if (dimr < 0 || dimc < 0)
                throw std::runtime_error("Matrix_base::dim_t out of range");
          }
       }
@@ -56,22 +57,22 @@ protected:
 
    Matrix_base() {}
 
-   Matrix_base(int r, int c)
-      : data(dim_t(r,c), r*c) {}
+   Matrix_base(Int r, Int c)
+      : data(dim_t(r, c), r*c) {}
 
    template <typename... TArgs>
-   Matrix_base(int r, int c, TArgs&&... args)
-      : data(dim_t(r,c), r*c, std::forward<TArgs>(args)...) {}
+   Matrix_base(Int r, Int c, TArgs&&... args)
+      : data(dim_t(r, c), r*c, std::forward<TArgs>(args)...) {}
 
-   Matrix_base(const shared_array_placement& place, int r, int c)
-      : data(place, dim_t(r,c), r*c) {}
+   Matrix_base(const shared_array_placement& place, Int r, Int c)
+      : data(place, dim_t(r, c), r*c) {}
 
    template <typename... TArgs>
-   Matrix_base(const shared_array_placement& place, int r, int c, TArgs&&... args)
-      : data(place, dim_t(r,c), r*c, std::forward<TArgs>(args)...) {}
+   Matrix_base(const shared_array_placement& place, Int r, Int c, TArgs&&... args)
+      : data(place, dim_t(r, c), r*c, std::forward<TArgs>(args)...) {}
 
    friend class ConcatRows<Matrix_base>;
-   template <typename, int> friend class alias;
+   template <typename, alias_kind> friend class alias;
 };
 
 /**
@@ -82,10 +83,9 @@ protected:
 
 template <typename E>
 class Matrix
-   : public GenericMatrix<Matrix<E>, E>
-   , protected Matrix_base<E>
-{
-   typedef Matrix_base<E> base_t;
+   : public Matrix_base<E>
+   , public GenericMatrix<Matrix<E>, E> {
+   using base_t = Matrix_base<E>;
    using typename base_t::dim_t;
 
    friend Matrix& make_mutable_alias(Matrix& alias, Matrix& owner)
@@ -99,34 +99,46 @@ protected:
       : bool_constant<(assess_iterator_value<Iterator, can_initialize, E>::value ||
                        assess_iterator_value<Iterator, can_initialize, Vector<E>>::value)> {};
 
+   template <typename Matrix2>
+   auto make_src_iterator(const Matrix2& m, std::enable_if_t<Matrix2::is_flat, void**> =nullptr)
+   {
+      return ensure(concat_rows(m), dense()).begin();
+   }
+
+   template <typename Matrix2>
+   auto make_src_iterator(const Matrix2& m, std::enable_if_t<!Matrix2::is_flat, void**> =nullptr)
+   {
+      return ensure(pm::rows(m), dense()).begin();
+   }
+
 public:
    using typename GenericMatrix<Matrix>::generic_type;
 
-   typedef E value_type;
-   typedef E& reference;
-   typedef const E& const_reference;
+   using value_type = E;
+   using reference = E&;
+   using const_reference = const E&;
 
    /// create as empty
    Matrix() {}
 
    /// create matrix with r rows and c columns, initialize all elements to 0
-   Matrix(int r, int c)
-      : base_t(r,c) {}
+   Matrix(Int r, Int c)
+      : base_t(r, c) {}
 
    template <typename E2,
-             typename=typename std::enable_if<can_initialize<E2, E>::value>::type>
+             typename=std::enable_if_t<can_initialize<E2, E>::value>>
    Matrix(std::initializer_list<std::initializer_list<E2>> l)
       : base_t(l.size(), count_columns(l), l.begin()) {}
 
    /// Create a matrix with given dimensions.  Elements are initialized from one or more input sequences.
    /// Elements are assumed to come in the row order.
-   template <typename... Iterator, typename=typename std::enable_if<mlist_and_nonempty<fits_as_input_iterator<Iterator>...>::value>::type>
-   Matrix(int r, int c, Iterator&&... src)
+   template <typename... Iterator, typename=std::enable_if_t<mlist_and_nonempty<fits_as_input_iterator<Iterator>...>::value>>
+   Matrix(Int r, Int c, Iterator&&... src)
       : base_t(r, c, ensure_private_mutable(std::forward<Iterator>(src))...) {}
 
    /// Create a matrix with given dimensions.  Elements are moved from one or more input sequences.
-   template <typename... Iterator, typename=typename std::enable_if<mlist_and_nonempty<fits_as_input_iterator<Iterator>...>::value>::type>
-   Matrix(int r, int c, polymake::operations::move, Iterator&&... src)
+   template <typename... Iterator, typename=std::enable_if_t<mlist_and_nonempty<fits_as_input_iterator<Iterator>...>::value>>
+   Matrix(Int r, Int c, polymake::operations::move, Iterator&&... src)
       : base_t(r, c, polymake::operations::move(), std::forward<Iterator>(src)...) {}
 
    /// Copy of a disguised Matrix object.
@@ -136,40 +148,39 @@ public:
    /// Copy of an abstract matrix of the same element type.
    template <typename Matrix2>
    Matrix(const GenericMatrix<Matrix2, E>& m)
-      : base_t(m.rows(), m.cols(), ensure(concat_rows(m), (dense*)0).begin()) {}
+      : base_t(m.rows(), m.cols(), make_src_iterator(m.top())) {}
 
    /// Copy of an abstract matrix with element conversion.
    template <typename Matrix2, typename E2>
    explicit Matrix(const GenericMatrix<Matrix2, E2>& m,
-                   typename std::enable_if<can_initialize<E2, E>::value>::type** = nullptr)
-      : base_t(m.rows(), m.cols(), ensure(concat_rows(m), (dense*)0).begin()) {}
+                   std::enable_if_t<can_initialize<E2, E>::value, void**> =nullptr)
+      : base_t(m.rows(), m.cols(), make_src_iterator(m.top())) {}
 
    template <typename Container>
    explicit Matrix(const Container& src,
-                   typename std::enable_if<isomorphic_to_container_of<Container, Vector<E>>::value>::type** = nullptr)
+                   std::enable_if_t<isomorphic_to_container_of<Container, Vector<E>>::value, void**> =nullptr)
       : base_t(src.size(), src.empty() ? 0 : get_dim(src.front()), src.begin()) {}
 
 protected:
-   Matrix(const shared_array_placement& place, int r, int c)
-      : base_t(place,r,c) {}
+   Matrix(const shared_array_placement& place, Int r, Int c)
+      : base_t(place, r, c) {}
 
    template <typename Iterator>
-   Matrix(const shared_array_placement& place, int r, int c, Iterator&& src)
+   Matrix(const shared_array_placement& place, Int r, Int c, Iterator&& src)
       : base_t(place, r, c, std::forward<Iterator>(src)) {}
 
-   void resize(const shared_array_placement& place, int r, int c)
+   void resize(const shared_array_placement& place, Int r, Int c)
    {
       this->data.resize(place, r*c);
-      this->data.get_prefix().dimr=r;
-      this->data.get_prefix().dimc=c;
+      this->data.get_prefix().dimr = r;
+      this->data.get_prefix().dimc = c;
    }
 public:
 
    Matrix& operator= (const Matrix& other) { assign(other); return *this; }
    using generic_type::operator=;
 
-   /// Exchange the contents of two matrices in a most efficient way. 
-   /// If at least one non-persistent object is involved, the operands must have equal dimensions. 
+   /// Exchange the contents of two matrices in a most efficient way.
    void swap(Matrix& m) { this->data.swap(m.data); }
 
    friend void relocate(Matrix* from, Matrix* to)
@@ -178,59 +189,59 @@ public:
    }
 
    /// Resize to new dimensions, added elements initialized with default constructor.
-   void resize(int r, int c)
+   void resize(Int r, Int c)
    {
-      const int dimc=cols(), dimr=rows();
-      if (c==dimc) {
+      const Int dimc = cols(), dimr = rows();
+      if (c == dimc) {
          this->data.resize(r*c);
-         this->data.get_prefix().dimr=r;
-      } else if (c<dimc && r<=dimr) {
-         *this=this->minor(sequence(0,r),sequence(0,c));
+         this->data.get_prefix().dimr = r;
+      } else if (c < dimc && r <= dimr) {
+         *this = this->minor(sequence(0, r), sequence(0, c));
       } else {
-         Matrix M(r,c);
-         if (c<dimc)
-            M.minor(sequence(0,dimr),All)=this->minor(All,sequence(0,c));
+         Matrix M(r, c);
+         if (c < dimc)
+            M.minor(sequence(0, dimr), All) = this->minor(All, sequence(0, c));
          else
-            M.minor(sequence(0,std::min(dimr,r)), sequence(0,dimc))=this->minor(sequence(0,std::min(dimr,r)),All);
-         *this=M;
+            M.minor(sequence(0, std::min(dimr, r)), sequence(0, dimc)) = this->minor(sequence(0, std::min(dimr, r)), All);
+         *this = M;
       }
    }
 
    template <typename E2>
-   typename std::enable_if<can_initialize<E2, E>::value, void>::type
-   assign(int r, int c, const E2& x)
+   std::enable_if_t<can_initialize<E2, E>::value>
+   assign(Int r, Int c, const E2& x)
    {
       this->data.assign(r*c, x);
-      this->data.get_prefix()=dim_t(r,c);
+      this->data.get_prefix() = dim_t(r, c);
    }
 
    /// Truncate to 0x0 matrix.
    void clear() { this->data.clear(); }
 
-   void clear(int r, int c)
+   void clear(Int r, Int c)
    {
       this->data.resize(r*c);
-      this->data.enforce_unshared().get_prefix()=dim_t(r,c);
+      this->data.enforce_unshared().get_prefix() = dim_t(r, c);
    }
 
    /// the number of rows of the matrix
-   int rows() const { return this->data.get_prefix().dimr; }
+   Int rows() const { return this->data.get_prefix().dimr; }
 
    /// the number of columns of the matrix
-   int cols() const { return this->data.get_prefix().dimc; }
+   Int cols() const { return this->data.get_prefix().dimc; }
 
-   reference operator() (int i, int j)
+   reference operator() (Int i, Int j)
    {
       if (POLYMAKE_DEBUG) {
-         if (i<0 || i>=this->rows() || j<0 || j>=this->cols())
+         if (i < 0 || i >= rows() || j < 0 || j >= cols())
             throw std::runtime_error("Matrix::operator() - index out of range");
       }
       return (*this->data)[i*cols()+j];
    }
-   const_reference operator() (int i, int j) const
+   const_reference operator() (Int i, Int j) const
    {
       if (POLYMAKE_DEBUG) {
-         if (i<0 || i>=this->rows() || j<0 || j>=this->cols())
+         if (i < 0 || i >= rows() || j < 0 || j >= cols())
             throw std::runtime_error("Matrix::operator() - index out of range");
       }
       return (*this->data)[i*cols()+j];
@@ -242,10 +253,10 @@ protected:
    template <typename Matrix2>
    void assign(const GenericMatrix<Matrix2>& m)
    {
-      const int r=m.rows(), c=m.cols();
-      this->data.assign(r*c, ensure(concat_rows(m), (dense*)0).begin());
-      this->data.get_prefix().dimr=r;
-      this->data.get_prefix().dimc=c;
+      const Int r = m.rows(), c = m.cols();
+      this->data.assign(r*c, make_src_iterator(m.top()));
+      this->data.get_prefix().dimr = r;
+      this->data.get_prefix().dimc = c;
    }
 
    template <typename Operation>
@@ -257,21 +268,21 @@ protected:
    template <typename Source2, typename Operation>
    void assign_op(const Source2& src2, const Operation& op)
    {
-      this->data.assign_op(ensure(concat_rows(src2), (dense*)0).begin(), op);
+      this->data.assign_op(make_src_iterator(src2), op);
    }
 
    // TODO: provide moving version of the following 4 methods
    template <typename Matrix2, typename E2>
    void append_rows(const GenericMatrix<Matrix2, E2>& m)
    {
-      this->data.append(concat_rows(m).dim(), ensure(concat_rows(m), (dense*)0).begin());
+      this->data.append(m.rows()*m.cols(), make_src_iterator(m.top()));
       this->data.get_prefix().dimr+=m.rows();
    }
 
    template <typename Vector2>
    void append_row(const GenericVector<Vector2>& v)
    {
-      this->data.append(v.dim(), ensure(v.top(), (dense*)0).begin());
+      this->data.append(v.dim(), ensure(v.top(), dense()).begin());
       this->data.get_prefix().dimr++;
    }
 
@@ -294,22 +305,11 @@ protected:
       this->data.assign(this->data.size(), x);
    }
 
-   void stretch_rows(int r)
-   {
-      this->data.enforce_unshared().get_prefix().dimr=r;
-   }
-
-   void stretch_cols(int c)
-   {
-      this->data.enforce_unshared().get_prefix().dimc=c;
-   }
-
    friend class ConcatRows<Matrix>;
    template <typename,typename> friend class GenericMatrix;
    friend class Rows<Matrix>;
    friend class Cols<Matrix>;
-   template <typename, typename> friend class RowChain;
-   template <typename, typename> friend class ColChain;
+   template <typename, typename> friend class BlockMatrix;
 };
 
 template <typename E>
@@ -320,7 +320,7 @@ class ConcatRows< Matrix_base<E> >
    : public plain_array< ConcatRows< Matrix_base<E> >, E >
    , public GenericVector< ConcatRows< Matrix_base<E> >, E> {
 protected:
-   ~ConcatRows();
+   ~ConcatRows() = delete;
    Matrix_base<E>& hidden() { return *reinterpret_cast<Matrix_base<E>*>(this); }
    const Matrix_base<E>& hidden() const { return *reinterpret_cast<const Matrix_base<E>*>(this); }
 
@@ -329,7 +329,7 @@ protected:
    E* get_data() { return *hidden().data; }
    const E* get_data() const { return *hidden().data; }
 public:
-   int size() const { return hidden().data.size(); }
+   Int size() const { return hidden().data.size(); }
 
    ConcatRows& operator= (const ConcatRows& other) { return ConcatRows::generic_type::operator=(other); }
    using ConcatRows::generic_type::operator=;
@@ -346,13 +346,13 @@ template <bool rowwise, typename BaseRef>
 class matrix_line_factory {
 public:
    typedef BaseRef first_argument_type;
-   typedef int second_argument_type;
-   typedef IndexedSlice<masquerade<ConcatRows, BaseRef>, Series<int,rowwise> > result_type;
+   typedef Int second_argument_type;
+   typedef IndexedSlice<masquerade<ConcatRows, BaseRef>, const Series<Int, rowwise>> result_type;
 
-   result_type operator() (BaseRef matrix, int start) const
+   result_type operator() (BaseRef matrix, Int start) const
    {
-      const typename deref<BaseRef>::type::dim_t& dims=matrix.data.get_prefix();
-      return result_type(matrix, Series<int,rowwise>(start, rowwise ? dims.dimc : dims.dimr, rowwise ? 1 : dims.dimc));
+      const auto& dims = matrix.data.get_prefix();
+      return result_type(matrix, Series<Int, rowwise>(start, rowwise ? dims.dimc : dims.dimr, rowwise ? 1 : dims.dimc));
    }
 };
 
@@ -372,29 +372,29 @@ struct binary_op_builder< matrix_line_factory<rowwise>, Iterator1, Iterator2, Re
 template <typename E>
 class Rows< Matrix<E> >
    : public modified_container_pair_impl< Rows< Matrix<E> >,
-                                          mlist< Container1Tag< constant_value_container< Matrix_base<E>& > >,
+                                          mlist< Container1Tag< same_value_container< Matrix_base<E>& > >,
                                                  Container2Tag< series >,
                                                  OperationTag< matrix_line_factory<true> >,
                                                  MasqueradedTop > > {
 protected:
    ~Rows();
 public:
-   constant_value_container< Matrix_base<E>& > get_container1()
+   auto get_container1()
    {
-      return this->hidden();
+      return same_value_container< Matrix_base<E>& >(static_cast<Matrix_base<E>&>(this->hidden()));
    }
-   const constant_value_container< const Matrix_base<E>& > get_container1() const
+   auto get_container1() const
    {
-      return this->hidden();
+      return same_value_container< const Matrix_base<E>& >(static_cast<const Matrix_base<E>&>(this->hidden()));
    }
    series get_container2() const
    {
       const Matrix<E>& me=this->hidden();
-      return series(0, me.rows(), std::max(me.cols(), 1));  // Matrix (R x 0) which can occur in a block matrix should not look like an empty container
+      return series(0, me.rows(), std::max(me.cols(), 1L));  // Matrix (R x 0) which can occur in a block matrix should not look like an empty container
    }
-   void resize(int n)
+   void resize(Int n)
    {
-      Matrix<E>& me=this->hidden();
+      Matrix<E>& me = this->hidden();
       me.resize(n, me.cols());
    }
 };
@@ -402,48 +402,48 @@ public:
 template <typename E>
 class Cols< Matrix<E> >
    : public modified_container_pair_impl< Cols< Matrix<E> >,
-                                          mlist< Container1Tag< constant_value_container< Matrix_base<E>& > >,
+                                          mlist< Container1Tag< same_value_container< Matrix_base<E>& > >,
                                                  Container2Tag< sequence >,
                                                  OperationTag< matrix_line_factory<false> >,
                                                  MasqueradedTop > > {
 protected:
    ~Cols();
 public:
-   constant_value_container< Matrix_base<E>& > get_container1()
+   auto get_container1()
    {
-      return this->hidden();
+      return same_value_container< Matrix_base<E>& >(static_cast<Matrix_base<E>&>(this->hidden()));
    }
-   const constant_value_container< const Matrix_base<E>& > get_container1() const
+   auto get_container1() const
    {
-      return this->hidden();
+      return same_value_container< const Matrix_base<E>& >(static_cast<const Matrix_base<E>&>(this->hidden()));
    }
    sequence get_container2() const
    {
       return sequence(0, this->hidden().cols());
    }
-   void resize(int n)
+   void resize(Int n)
    {
-      Matrix<E>& me=this->hidden();
+      Matrix<E>& me = this->hidden();
       me.resize(me.rows(), n);
    }
 };
 
-template <typename TMatrix, typename E, typename Permutation> inline
-typename std::enable_if<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>::type
+template <typename TMatrix, typename E, typename Permutation>
+std::enable_if_t<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>
 permuted_rows(const GenericMatrix<TMatrix, E>& m, const Permutation& perm)
 {
-   if (POLYMAKE_DEBUG || !Unwary<TMatrix>::value) {
+   if (POLYMAKE_DEBUG || is_wary<TMatrix>()) {
       if (m.rows() != perm.size())
          throw std::runtime_error("permuted_rows - dimension mismatch");
    }
    return Matrix<E>(m.rows(), m.cols(), select(rows(m),perm).begin());
 }
 
-template <typename TMatrix, typename E, typename Permutation> inline
-typename std::enable_if<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>::type
+template <typename TMatrix, typename E, typename Permutation>
+std::enable_if_t<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>
 permuted_cols(const GenericMatrix<TMatrix, E>& m, const Permutation& perm)
 {
-   if (POLYMAKE_DEBUG || !Unwary<TMatrix>::value) {
+   if (POLYMAKE_DEBUG || is_wary<TMatrix>()) {
       if (m.cols() != perm.size())
          throw std::runtime_error("permuted_cols - dimension mismatch");
    }
@@ -452,11 +452,11 @@ permuted_cols(const GenericMatrix<TMatrix, E>& m, const Permutation& perm)
    return result;
 }
 
-template <typename TMatrix, typename E, typename Permutation> inline
-typename std::enable_if<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>::type
+template <typename TMatrix, typename E, typename Permutation>
+std::enable_if_t<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>
 permuted_inv_rows(const GenericMatrix<TMatrix, E>& m, const Permutation& perm)
 {
-   if (POLYMAKE_DEBUG || !Unwary<TMatrix>::value) {
+   if (POLYMAKE_DEBUG || is_wary<TMatrix>()) {
       if (m.rows() != perm.size())
          throw std::runtime_error("permuted_inv_rows - dimension mismatch");
    }
@@ -465,11 +465,11 @@ permuted_inv_rows(const GenericMatrix<TMatrix, E>& m, const Permutation& perm)
    return result;
 }
 
-template <typename TMatrix, typename E, typename Permutation> inline
-typename std::enable_if<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>::type
+template <typename TMatrix, typename E, typename Permutation>
+std::enable_if_t<TMatrix::is_nonsymmetric && !TMatrix::is_sparse, Matrix<E>>
 permuted_inv_cols(const GenericMatrix<TMatrix, E>& m, const Permutation& perm)
 {
-   if (POLYMAKE_DEBUG || !Unwary<TMatrix>::value) {
+   if (POLYMAKE_DEBUG || is_wary<TMatrix>()) {
       if (m.cols() != perm.size())
          throw std::runtime_error("permuted_inv_cols - dimension mismatch");
    }
@@ -486,10 +486,9 @@ namespace polymake {
 
 namespace std {
 
-   /// Exchange the contents of two matrices in a most efficient way. 
-   /// If at least one non-persistent object is involved, the operands must have equal dimensions. 
-   template <typename E> inline
-   void swap(pm::Matrix<E>& m1, pm::Matrix<E>& m2) { m1.swap(m2); }
+template <typename E>
+void swap(pm::Matrix<E>& m1, pm::Matrix<E>& m2) { m1.swap(m2); }
+
 }
 
 #endif // POLYMAKE_MATRIX_H
