@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -21,7 +22,7 @@
 
 namespace pm {
 
-template <bool left_to_right=true, typename number_type=int>
+template <bool left_to_right = true, typename number_type = Int>
 class MultiDimCounter {
 public:
    typedef bidirectional_iterator_tag iterator_category;
@@ -41,12 +42,13 @@ public:
 
    template <typename Container>
    explicit MultiDimCounter(const Container& limits)
-      : my_start(limits.size()), my_counter(my_start.size()),
-        my_limits(my_start.size(), limits.begin()),
-        my_at_end(my_start.empty())
+      : my_start(limits.size())
+      , my_counter(my_start.size())
+      , my_limits(my_start.size(), limits.begin())
+      , my_at_end(my_start.empty())
    {
       if (POLYMAKE_DEBUG) {
-         for (int i=0, n=my_start.size(); i<n; ++i)
+         for (Int i = 0, n = my_start.size(); i < n; ++i)
             if (my_limits[i] <= 0)
                throw std::runtime_error("MultiDimCounter: wrong limit value");
       }
@@ -54,12 +56,13 @@ public:
 
    template <typename Container1, typename Container2>
    MultiDimCounter(const Container1& start, const Container2& limits)
-      : my_start(start.size(), start.begin()), my_counter(my_start),
-        my_limits(my_start.size(), limits.begin()),
-        my_at_end(my_start.empty())
+      : my_start(start.size(), start.begin())
+      , my_counter(my_start)
+      , my_limits(my_start.size(), limits.begin())
+      , my_at_end(my_start.empty())
    {
       if (POLYMAKE_DEBUG) {
-         for (int i=0, n=my_start.size(); i<n; ++i)
+         for (Int i = 0, n = my_start.size(); i < n; ++i)
             if (my_limits[i] <= my_start[i])
                throw std::runtime_error("MultiDimCounter: wrong limit/start values");
       }
@@ -94,16 +97,16 @@ public:
          if (values.size() != my_limits.size())
             throw std::runtime_error("MultiDimCounter::set - dimension mismatch");
 
-         typename value_type::iterator l=my_limits.begin();
-         typename Container::const_iterator v=values.begin();
-         for (typename Entire<value_type>::iterator s=entire(my_start);  !s.at_end();  ++s, ++l, ++v)
+         auto l=my_limits.begin();
+         auto v=values.begin();
+         for (auto s=entire(my_start);  !s.at_end();  ++s, ++l, ++v)
             if (*v < *s || *v >= *l)
                throw std::runtime_error("MultiDimCounter::set - value out of range");
       }
       copy_range(values.begin(), entire(my_counter));
    }
 
-   void set_digit(int digit, typename function_argument<number_type>::type value)
+   void set_digit(Int digit, const number_type& value)
    {
       if (POLYMAKE_DEBUG) {
          if (digit >= my_limits.size())
@@ -129,24 +132,25 @@ template <bool left_to_right, typename number_type>
 MultiDimCounter<left_to_right, number_type>&
 MultiDimCounter<left_to_right, number_type>::operator++ ()
 {
-   const int last = my_limits.size()-1;
+   const Int last = my_limits.size()-1;
 
-   if (left_to_right)
-      for (int digit = 0; (++my_counter[digit]) >= my_limits[digit]; ++digit)
+   if (left_to_right) {
+      for (Int digit = 0; ++my_counter[digit] >= my_limits[digit]; ++digit)
          if (digit < last) {
             my_counter[digit] = my_start[digit];
          } else {
-            my_at_end = true;  break;
+            my_at_end = true;
+            break;
          }
-
-   else
-      for (int digit = last; (++my_counter[digit]) >= my_limits[digit]; --digit)
+   } else {
+      for (Int digit = last; ++my_counter[digit] >= my_limits[digit]; --digit)
          if (digit > 0) {
             my_counter[digit] = my_start[digit];
          } else {
-            my_at_end = true;  break;
+            my_at_end = true;
+            break;
          }
-
+   }
    return *this;
 }
    
@@ -154,24 +158,25 @@ template <bool left_to_right, typename number_type>
 MultiDimCounter<left_to_right, number_type>&
 MultiDimCounter<left_to_right, number_type>::operator-- ()
 {
-   const int last = my_limits.size()-1;
+   const Int last = my_limits.size()-1;
 
-   if (left_to_right)
-      for (int digit = 0; (--my_counter[digit]) < my_start[digit]; ++digit)
+   if (left_to_right) {
+      for (Int digit = 0; --my_counter[digit] < my_start[digit]; ++digit)
          if (digit < last) {
             my_counter[digit] = my_limits[digit]-1;
          } else {
-            my_at_end = true;  break;
+            my_at_end = true;
+            break;
          }
-
-   else
-      for (int digit = last; (--my_counter[digit]) < my_start[digit]; --digit)
+   } else {
+      for (Int digit = last; --my_counter[digit] < my_start[digit]; --digit)
          if (digit > 0) {
             my_counter[digit] = my_limits[digit]-1;
          } else {
-            my_at_end = true;  break;
+            my_at_end = true;
+            break;
          }
-
+   }
    return *this;
 }
    
