@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -21,20 +22,18 @@ namespace pm { namespace perl { namespace glue {
 ostreambuf_bridge::ostreambuf_bridge(pTHX_ GV* gv_arg)
 {
    if (gv_arg && GvIO(gv_arg) && IoOFP(GvIO(gv_arg))) {
-      pi=getTHX;
-      gv=gv_arg;
+      gv = gv_arg;
       setp(buf, buf+sizeof(buf));
    } else {
-      pi=NULL;
-      gv=Nullgv;
+      gv = nullptr;
    }
 }
 
 ostreambuf_bridge::int_type ostreambuf_bridge::overflow(int_type c)
 {
    if (handover(false)) {
-      if (!traits_type::eq(c, traits_type::eof())) {
-         *pptr() = c;
+      if (!traits_type::eq_int_type(c, traits_type::eof())) {
+         *pptr() = traits_type::to_char_type(c);
          pbump(1);
       }
       return traits_type::not_eof(c);
@@ -45,18 +44,18 @@ ostreambuf_bridge::int_type ostreambuf_bridge::overflow(int_type c)
 
 bool ostreambuf_bridge::handover(bool with_sync)
 {
-   dTHXa(pi);
-   IO* io=GvIO(gv);
-   if (io == NULL)
+   dTHX;
+   IO* io = GvIO(gv);
+   if (!io)
       throw std::runtime_error("internal error: STDOUT IO handle disappeared");
    PerlIO* fp=IoOFP(io);
-   if (fp == NULL)
+   if (!fp)
       throw std::runtime_error("internal error: STDOUT IO handle not opened for writing");
-   int out_size=pptr() - pbase();
-   if (out_size>0) {
+   const std::streamsize out_size = pptr() - pbase();
+   if (out_size > 0) {
       if (PerlIO_write(fp, buf, out_size) != out_size)
          throw std::runtime_error("internal error: buffered STDOUT not consumed completely");
-      setp(buf, buf+sizeof(buf));
+      setp(buf, buf + sizeof(buf));
    }
    if (with_sync)
       return PerlIO_flush(fp) != EOF;
@@ -70,13 +69,13 @@ int ostreambuf_bridge::sync()
 
 void connect_cout(pTHX)
 {
-   static ostreambuf_bridge cout_bridge_buf(aTHX_ gv_fetchpv("STDOUT", false, SVt_PVGV));
+   static ostreambuf_bridge cout_bridge_buf(aTHX_ get_named_variable(aTHX_ "STDOUT", SVt_PVGV));
    cout.rdbuf(&cout_bridge_buf);
 }
 
 }
 
-std::ostream cout(NULL);
+std::ostream cout(nullptr);
 
 } }
 
