@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2024
+#  Copyright (c) 1997-2020
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -49,12 +49,11 @@ require JSON;
 # Global variables
 #
 
-declare $Version = "4.14";
+declare $Version = "4.3";
 declare $VersionNumber = eval "v$Version";    # for string comparisons with vM.N literals
 
 declare ($Scope,                # Scope object for the current cycle
          $PrivateDir,           # where the user's private settings, wrappers, etc. dwell
-         $Settings,             # user's preferences, custom variables, auto-configuration
         );
 
 declare $Shell = new NoShell;   # alternatively: Shell object listening to the console or some pipe
@@ -80,10 +79,10 @@ require Polymake::TempChangeDir;
 require Polymake::OverwriteFile;
 require Polymake::Overload;
 require Polymake::Schema;
-require Polymake::Core::UserSettings;
+require Polymake::Core::Customize;
 require Polymake::Core::Preference;
-require Polymake::Core::Help;
 require Polymake::User;
+require Polymake::Core::Help;
 require Polymake::Core::PropertyType;
 require Polymake::Core::Property;
 require Polymake::Core::Permutation;
@@ -99,15 +98,17 @@ require Polymake::Core::Extension;
 require Polymake::Core::CPlusPlus;
 require Polymake::Core::StoredScript;
 require Polymake::Core::RuleFilter;
+require Polymake::Core::UserSettings;
 
 package Polymake::Core;
 
+declare $Custom = new Customize;
 declare $Prefs = new Preference;
 declare $enable_plausibility_checks = true;
 
-my @settings_callbacks;
-sub add_settings_callback {
-   push @settings_callbacks, @_;
+my @custom_blocks;
+sub add_custom_vars {
+   push @custom_blocks, @_;
 }
 
 ########################################################################
@@ -142,7 +143,7 @@ sub greeting {
 
    my @messages = ("polymake version $full_version", <<'.' . $mainURL . "\n", <<'.');
 
-Copyright (c) 1997-2024
+Copyright (c) 1997-2020
 Ewgenij Gawrilow, Michael Joswig, and the polymake team
 Technische Universität Berlin, Germany
 .
@@ -157,9 +158,7 @@ There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR P
 # initialize some modules in proper order
 # "config path" =>
 sub init {
-   $Settings = Core::UserSettings::init(@_);
-   $_->($Settings) for @settings_callbacks;
-   @settings_callbacks = ();
+   Core::UserSettings::init(@_, @custom_blocks);
    Core::Extension::init();
    Core::CPlusPlus::init();
 }
