@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2023
+#  Copyright (c) 1997-2020
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -420,7 +420,7 @@ sub instantiate_permutation {
 sub lookup_overridden_property {
    my ($self, $prop) = @_;
    foreach my $super (@{$self->linear_isa}) {
-      if ($super->full_spez_for != $self && !$super->isa($prop->overrides_for) && $super->isa($prop->defined_for)) {
+      if (!$super->isa($prop->overrides_for) && $super->isa($prop->defined_for)) {
          return lookup_property($super, $prop->overrides);
       }
    }
@@ -635,19 +635,7 @@ sub get_producers_of {
       if (defined(my $own_prod = $self->producers->{$key})) {
          @list = @$own_prod;
       }
-      if (!defined($stop_after) && defined($prop->defined_for)) {
-         $stop_after = $prop->defined_for->pure_type;
-         if (defined($stop_after->generic)) {
-            $stop_after = $stop_after->generic;
-         } elsif (!defined($stop_after->abstract)) {
-            # this is not an abstract super type so we need to find the last
-            # matching specialization to check all of them for rules
-            my @siblings = grep {defined($_->full_spez_for) && $_->full_spez_for->pure_type == $stop_after} @{$stop_after->linear_isa};
-            if (@siblings > 0) {
-               $stop_after = $siblings[-1];
-            }
-         }
-      }
+      $stop_after //= $prop->defined_for;
       if ($stop_after != $self) {
          foreach my $super_proto (@{$self->linear_isa}) {
             $super_proto->all_producers->{$key} //= 0;   # mark for cache invalidation
@@ -799,26 +787,32 @@ sub override_rule {
 ####################################################################################
 sub find_rule_label {
    my ($self, $pattern)=@_;
-   $self->application->find_rule_label($pattern)
-}
-
-sub all_production_rules {
-   my ($self) = @_;
-   map { @{$_->production_rules} } $self, @{$self->linear_isa}
+   $self->application->prefs->find_label($pattern)
 }
 
 sub find_rules_by_pattern {
-   my ($self, $pattern) = @_;
-   Rule::find_by_pattern($self, $pattern, sub { $self->isa($_->defined_for) })
+   my ($self, $pattern)=@_;
+   if ($pattern =~ /^ $hier_id_re $/xo) {
+      # specified by label
+      my $label=$self->find_rule_label($pattern)
+        or die "unknown label \"$pattern\"\n";
+      grep { $self->isa($_->defined_for) } $label->list_all_rules
+
+   } elsif ($pattern =~ /:/) {
+      # specified by header:
+      Rule::header_search_pattern($pattern);
+      grep { $_->header =~ $pattern } map { @{$_->production_rules} } $self, @{$self->linear_isa}
+
+   } else {
+      die "invalid rule search pattern: expected a label or a complete header in the form \"OUTPUT : INPUT\"\n";
+   }
 }
 
 sub disable_rules {
-   my ($self, $pattern) = @_;
-   my @rules = $self->find_rules_by_pattern($pattern)
+   my @rules=&find_rules_by_pattern
      or die "no matching rules found\n";
    Scheduler::temp_disable_rules(@rules);
 }
-
 ####################################################################################
 sub add_method_rule {
    my ($self, $header, $code, $name)=@_;
@@ -1020,7 +1014,7 @@ sub push_code {
 sub resolve {
    my ($self, $args)=@_;
    if (defined (my $rulelist=&Overload::Node::resolve)) {
-      (Scheduler::resolve_rules($args->[0], $rulelist) || croak( "could not provide all required input properties" ))->code;
+      (Scheduler::resolve_rules($args->[0], $rulelist) // croak( "could not provide all required input properties" ))->code;
    } else {
       undef
    }
@@ -1326,11 +1320,10 @@ sub create_augmentation {
 }
 ####################################################################################
 sub find_rule_label {
-   my ($self, $pattern) = @_;
-   $self->application->find_rule_label($pattern) // do {
-      my $pure_type_app = $self->pure_type->application;
-      if ($pure_type_app != $self->application) {
-         $pure_type_app->find_rule_label($pattern)
+   &BigObjectType::find_rule_label // do {
+      my $pure_type_app=$_[0]->pure_type->application;
+      if ($pure_type_app != $_[0]->application) {
+         $pure_type_app->prefs->find_label($_[1])
       } else {
          undef
       }
