@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2024
+#  Copyright (c) 1997-2020
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -311,9 +311,9 @@ sub accept_subobject : method {
    $value->is_temporary= $temp || defined($parent_obj->parent) && $parent_obj->is_temporary;
 
    if (defined($value->transaction)) {
-      if ($value->cleanup_table) {
-         Transaction::merge_temporaries($value->transaction->temporaries, delete $value->cleanup_table->{$value});
-         $value->cleanup_table=0;
+      if ($value->has_cleanup) {
+         Transaction::merge_temporaries($value->transaction->temporaries, delete $Scope->cleanup->{$value});
+         $value->has_cleanup=0;
       }
       if (defined($parent_obj->transaction)) {
          $parent_obj->transaction->descend($value, 1) unless ($temp && defined($parent_obj->transaction->rule));
@@ -323,11 +323,11 @@ sub accept_subobject : method {
    } elsif (defined($parent_obj->transaction)) {
       unless ($temp && defined($parent_obj->transaction->rule)) {
          ## FIXME: suspicious logical expression
-         if (not($self->flags & Flags::is_subobject_array) || $value->cleanup_table) {
+         if (not($self->flags & Flags::is_subobject_array) || $value->has_cleanup) {
             $parent_obj->transaction->descend($value, !($self->flags & Flags::is_permutation));
-            if ($value->cleanup_table) {
-               $value->transaction->temporaries = delete $value->cleanup_table->{$value};
-               $value->cleanup_table = 0;
+            if ($value->has_cleanup) {
+               $value->transaction->temporaries = delete $Scope->cleanup->{$value};
+               $value->has_cleanup = 0;
             }
          }
       }
@@ -516,6 +516,7 @@ RefHash::allow(__PACKAGE__);
 my $prop_key=\(1);
 my $subobj_key=\(2);
 my $defined_for_key=\(3);
+my $in_twins_key=\(4);
 
 sub new {
    my ($pkg, $prop, $prop_down, $subobj_prop)=@_;
@@ -535,6 +536,7 @@ sub property { $_[0]->{$prop_key} }
 sub subobject_property { $_[0]->{$subobj_key} }
 sub defined_for { $_[0]->{$defined_for_key} }
 sub property_key { &property->key }
+*produced_in_twins=\&Property::produced_in_twins;
 
 ####################################################################################
 package Polymake::Core::Property;
@@ -551,6 +553,20 @@ sub get_prod_key {
    $hash
 }
 
+sub memorize_produced_in_twin {
+   my ($self, $hash)=@_;
+   $hash->{$in_twins_key}->{$self->key} //= $self;
+}
+
+sub produced_in_twins {
+   my ($self)=@_;
+   if (defined (my $twins=$self->key->{$in_twins_key})) {
+      values %$twins
+   } else {
+      ()
+   }
+}
+
 ####################################################################################
 package Polymake::Core::Property::NewMultiInstance;
 
