@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2024
+#  Copyright (c) 1997-2020
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -25,27 +25,6 @@ if you already have an up-to-date perl interpreter somewhere else,
 you can specify its location on the command line:
 
 ./configure PERL=/path/to/my/new/perl [other options ...]
-.
-      exit(1);
-   } elsif ($] >= 5.042) {
-      print STDERR <<".";
-*************
-*** ERROR ***
-*************
-
-polymake has not been checked for compatibility with perl 5.42 or newer;
-your perl interpreter says it is $].
-
-If you already have another (older) perl interpreter somewhere else, you can
-specify its location on the command line:
-
-./configure PERL=/path/to/my/new/perl [other options ...]
-
-You can install a custom perl version in your home directory using perlbrew
-(https://perlbrew.pl). Make sure to append '-Duseshrplib' to the install
-command if you want to use libpolymake (e.g. for the jupyter interface) and to
-install all required perl modules which are listed after running configure
-again with the new perl.
 .
       exit(1);
    }
@@ -107,8 +86,6 @@ $Polymake::DeveloperMode = -d "$root/testscenarios";
 
 my $BuildDir = $options{build} ? "build.$options{build}" : "build";
 my $perlxpath = "perlx/$Config::Config{version}/$Config::Config{archname}";
-my $perlextraflags = "";
-my $autogold = 0;
 
 load_enabled_bundled_extensions();
 parse_command_line(\@ARGV, $repeating_config);
@@ -242,7 +219,7 @@ Allowed options (and their default values) are:
    $^O eq "darwin" and
    print STDERR <<'---';
   --with-fink=PATH         fink installation directory. You can pass "default" as argument if fink is installed into its default location ( /sw )
-  --with-brew=PATH         homebrew installation directory. You can pass "default" as argument if brew is installed into its default location ( /usr/local for intel Macs or /opt/homebrew for silicon Macs)
+  --with-brew=PATH         homebrew installation directory. You can pass "default" as argument if brew is installed into its default location ( /usr/local )
 .
 ---
    print STDERR <<"---";
@@ -644,7 +621,6 @@ int main() {
          undef $build_error;
       } else {
          $LDFLAGS .= " -fuse-ld=gold";
-         $autogold = 1;
       }
    }
    $build_error //= build_test_program($cxx_tell_version);
@@ -782,7 +758,7 @@ Please investigate and reconfigure.
            $cppver >= 201305 and
                defined($CLANGversion) and v_cmp($CLANGversion, "3.5") < 0
           ) {
-      # C++ standard older than C++14 won't work (C++1y from clang 3.4 is also ok)
+      # C++ standard older than C++14 wont work (C++1y from clang 3.4 is also ok)
       die "C++ standard version ($cppver) too old, C++14 or later is required. Please omit any '-std=' options.\n";
    }
 
@@ -870,20 +846,11 @@ If you have renamed the main fink program, please specify the top directory: --w
 #####################################################
 sub check_brew {
    $BrewBase=$options{brew};
-   my $local_arch = `uname -m`;
-   chomp $local_arch;
-   if ( $BrewBase eq "default" || ( $local_arch == "x86_64" && $BrewBase eq "/usr/local" ) || ( $local_arch == "arm64" && $BrewBase eq '/opt/homebrew' ) ) {
-      $BrewBase = $local_arch eq "x86_64" ? '/usr/local' : '/opt/homebrew';
+   if ( $BrewBase eq "default" ) {
+      $BrewBase = '/usr/local';
       unless (-f "$BrewBase/bin/brew") {
          die "brew installation corrupt: $BrewBase/bin/brew not found\n";
       }
-   } elsif( $BrewBase eq "bottle" ) {
-      $ADDITIONAL_PERL_INCLUDES = "";
-      my @perl_paths = split(/:/, "$ENV{PERL5LIB}");
-      foreach (@perl_paths) {
-         $ADDITIONAL_PERL_INCLUDES .= " -I$_";
-      }
-      $BrewBase = '#{HOMEBREW_PREFIX}';
    } else {
       if (-d $BrewBase) {
          unless (-f "$BrewBase/bin/brew") {
@@ -937,10 +904,12 @@ sub determine_architecture {
    print "determining architecture ... ";
    if ($^O eq "darwin") {
       if ( !defined($FinkBase) && !defined($BrewBase) ) {
-         $Arch //= `uname -m`;
-         chomp $Arch;
-         if ($Arch ne "arm64" && $Arch ne "i386" && $Arch ne "x86_64") {
-            die "Invalid architecture $Arch for Mac OS: allowed values are i386, x86_64 and arm64.\n";
+         if (defined $Arch) {
+            if ($Arch ne "i386" && $Arch ne "x86_64") {
+               die "Invalid architecture $Arch for Mac OS: allowed values are i386 and x86_64.\n";
+            }
+         } else {
+            $Arch = "x86_64";
          }
       }
       $ARCHFLAGS= $NeedsArchFlag ? "-arch $Arch" : "";
@@ -984,26 +953,16 @@ sub collect_compiler_specific_options {
       $CflagsSuppressWarnings="-Wno-unused-result";
       # gcc-specific flags
       $CXXFLAGS .= " -Wshadow -Wlogical-op -Wconversion -Wzero-as-null-pointer-constant -Wno-parentheses -Wno-error=unused-function";
-      if (v_cmp($GCCversion, "8") < 0) {
-         $CXXFLAGS .= " -Wno-float-conversion -Wno-strict-overflow";
-      }
-      if (v_cmp($GCCversion, "6.3") >= 0 && v_cmp($GCCversion, "7") < 0) {
+      if (v_cmp($GCCversion, "6.3.0") >= 0 && v_cmp($GCCversion, "7.0.0") < 0) {
          $CXXFLAGS .= " -Wno-maybe-uninitialized";
       }
-      if (v_cmp($GCCversion, "9.1") >= 0) {
+      if (v_cmp($GCCversion, "9.1.0") >= 0) {
          $CXXFLAGS .= " -Wno-stringop-overflow";
          $CflagsSuppressWarnings.=" -Wno-stringop-overflow";
       }
-      if (v_cmp($GCCversion, "10") >= 0) {
+      if (v_cmp($GCCversion, "10.0.0") >= 0) {
          $CXXFLAGS .= " -Wno-array-bounds";
       }
-      if (v_cmp($GCCversion, "11") >= 0) {
-         $CXXFLAGS .= " -Wno-maybe-uninitialized -Wno-free-nonheap-object";
-      }
-      if (v_cmp($GCCversion, "14") >= 0) {
-         # due to false positives
-         $CXXFLAGS .= " -Wno-dangling-reference";
-      }
 
    } elsif (defined($ICCversion)) {
       $CsharedFLAGS="-fPIC";
@@ -1254,65 +1213,6 @@ The complete error log follows:
    }
 }
 
-sub check_gmpxx {
-   # check GMP C++ bindings
-   my $build_error=build_test_program(<<'---', LIBS => "-lgmpxx -lgmp");
-#include <cstddef>
-#include <gmpxx.h>
-int main() {
-   mpz_class z(7);
-   mpz_class y(z-z);
-   return y.get_si();
-}
----
-   if ($?==0) {
-      my $run_error = run_test_program();
-      if ($?) {
-         die "Could not run a test program linked to the C++ version of the GNU Multiprecision Library (GMP).\n",
-             "Probably the shared library libgmpxx.$Config::Config{dlext} is missing or of an incompatible machine type:\n$run_error\n";
-      }
-   } else {
-      die "Could not compile a test program checking for C++ bindings of the GNU Multiprecision Library (GMP).\n",
-          "The most probable reasons are that a gmpxx package is missing, lacking the developer's subpackage \n",
-          "or GMP was configured without C++ support (--enable-cxx).\n",
-          "Please refer to the installation instructions at $Wiki/howto/install.\n",
-          "The complete error log follows:\n", $build_error;
-   }
-}
-
-sub check_gmpxx_ostream {
-   my $extraflags = "";
-   # check GMP C++ library
-OSTREAM_CHECK:
-   my $build_error=build_test_program(<<'---', CXXFLAGS => "$extraflags", LIBS => "$ARCHFLAGS -lgmpxx -lgmp");
-#include <cstddef>
-#include <gmpxx.h>
-#include <iostream>
-
-#ifdef PM_MIXED_OSTREAM
-std::ostream& operator<< (std::ostream &s, mpq_srcptr r) {
-   return s << 1;
-}
-#endif
-int main() {
-   mpq_class x(7,3);
-   std::cout << x << std::endl;
-   return 0;
-}
----
-      my $run_error = run_test_program() if $? == 0;
-      if ($?!=0) {
-         if ($extraflags) {
-            die "Could not build and run a test program checking the C++ library used by the GNU Multiprecision Library (GMP):\nbuild: $build_error\nrun:$run_error\n";
-         } else {
-            $extraflags = " -DPM_MIXED_OSTREAM";
-            goto OSTREAM_CHECK;
-         }
-      } elsif ($extraflags) {
-         $CXXFLAGS .= $extraflags;
-      }
-}
-
 ##########################################################
 sub locate_boost_headers {
    my $boost_path=$options{boost};
@@ -1449,8 +1349,7 @@ Otherwise, reconfigure and reinstall your perl.
          $_ =~ s/(?:^|\s+)-arch\s+\w+//g for $perlcflags, $perlldflags; 
       }
    }
-RETRYLIBPERL:
-   my $build_error=build_test_program(<<'---', CXXFLAGS => (defined($CLANGversion) && "-Wno-reserved-user-defined-literal ")."$perlcflags $perlextraflags", LDFLAGS => "$ARCHFLAGS $perlldflags" );
+   my $build_error=build_test_program(<<'---', CXXFLAGS => (defined($CLANGversion) && "-Wno-reserved-user-defined-literal ").$perlcflags, LDFLAGS => "$ARCHFLAGS $perlldflags" );
 #include <EXTERN.h>
 #include <perl.h>
 
@@ -1489,20 +1388,6 @@ perl-devel or libperl-dev.  Please look for such a package and install it.
 ---
       }
    } else {
-      if (defined($GCCversion) && $perlextraflags !~ /-D_Thread_local/ && $build_error =~ /error:.+_Thread_local.+does not name a type/s) {
-         # The PERL_THREAD_LOCAL macro might be set to _Thread_local (since perl 5.35.5).
-         # This is defined in the C11 standard and supported by all relevant gcc versions.
-         # But g++ (gcc in C++ mode) does not accept _Thread_local so we define that to thread_local instead.
-         # clang and clang++ both accept _Thread_local.
-         $perlextraflags .= " -D_Thread_local=thread_local";
-         goto RETRYLIBPERL;
-      }
-      if ($autogold && $LDFLAGS =~ /-fuse-ld=gold/ && $build_error =~ /ld\.gold.*unknown -z option/s) {
-         # some distributions have extra flags in the perl settings that the gold linker
-         # doesn't understand, so switch back to the default linker in that case
-         $LDFLAGS =~ s/-fuse-ld=gold//g;
-         goto RETRYLIBPERL;
-      }
       $error = <<"---";
 Could not compile a test program for the libperl.$Config::Config{so} shared library.
 The build error is as follows:
@@ -1662,9 +1547,6 @@ sub configure_enabled_bundled_extensions {
                print "failed";
                bundled_ext_error_msg($ext, $@);
                $enable=0;
-            } elsif ($result =~ /^disabled/) {
-               $enable=0;
-               print $result;
             } else {
                print "ok", $result ? " ($result)":"";
             }
@@ -1872,7 +1754,7 @@ sub write_perl_specific_configuration_file {
 
    print $conf <<"---";
 PERL=$Config::Config{perlpath}
-CXXglueFLAGS=$includePerlCore$Config::Config{archlibexp}/CORE $Config::Config{ccflags} $perlextraflags -DPerlVersion=$PerlVersion $no_warn
+CXXglueFLAGS=$includePerlCore$Config::Config{archlibexp}/CORE $Config::Config{ccflags} -DPerlVersion=$PerlVersion $no_warn
 LIBperlFLAGS=-L$Config::Config{archlib}/CORE -lperl $Config::Config{ccdlflags}
 ExtUtils_xsubpp=$xsubpp
 ExtUtils_typemap=$typemap
